package v1alpha1

import "k8s.io/client-go/applyconfigurations/apiserverinternal/v1alpha1"

Index

Types

type ServerStorageVersionApplyConfiguration

type ServerStorageVersionApplyConfiguration struct {
	// apiServerID is the ID of the reporting API server.
	APIServerID *string `json:"apiServerID,omitempty"`
	// encodingVersion the API server encodes the object to when persisting it in
	// the backend (e.g., etcd).
	EncodingVersion *string `json:"encodingVersion,omitempty"`
	// decodableVersions are the encoding versions the API server can handle to decode.
	// The API server can decode objects encoded in these versions.
	// The encodingVersion must be included in the decodableVersions.
	DecodableVersions []string `json:"decodableVersions,omitempty"`
	// servedVersions lists all versions the API server can serve.
	// DecodableVersions must include all ServedVersions.
	ServedVersions []string `json:"servedVersions,omitempty"`
}

ServerStorageVersionApplyConfiguration represents a declarative configuration of the ServerStorageVersion type for use with apply.

An API server instance reports the version it can decode and the version it encodes objects to when persisting objects in the backend.

func ServerStorageVersion

func ServerStorageVersion() *ServerStorageVersionApplyConfiguration

ServerStorageVersionApplyConfiguration constructs a declarative configuration of the ServerStorageVersion type for use with apply.

func (*ServerStorageVersionApplyConfiguration) WithAPIServerID

WithAPIServerID sets the APIServerID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIServerID field is set to the value of the last call.

func (*ServerStorageVersionApplyConfiguration) WithDecodableVersions

WithDecodableVersions adds the given value to the DecodableVersions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the DecodableVersions field.

func (*ServerStorageVersionApplyConfiguration) WithEncodingVersion

WithEncodingVersion sets the EncodingVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the EncodingVersion field is set to the value of the last call.

func (*ServerStorageVersionApplyConfiguration) WithServedVersions

WithServedVersions adds the given value to the ServedVersions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the ServedVersions field.

type StorageVersionApplyConfiguration

type StorageVersionApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// metadata is the standard object metadata.
	// The name is <group>.<resource>.
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// spec is an empty spec. It is here to comply with Kubernetes API style.
	Spec *apiserverinternalv1alpha1.StorageVersionSpec `json:"spec,omitempty"`
	// status on the version the API server instance can decode from and
	// encode objects to when persisting objects in the backend.
	Status *StorageVersionStatusApplyConfiguration `json:"status,omitempty"`
}

StorageVersionApplyConfiguration represents a declarative configuration of the StorageVersion type for use with apply.

Storage version of a specific resource.

func ExtractStorageVersion

func ExtractStorageVersion(storageVersion *apiserverinternalv1alpha1.StorageVersion, fieldManager string) (*StorageVersionApplyConfiguration, error)

ExtractStorageVersion extracts the applied configuration owned by fieldManager from storageVersion. If no managedFields are found in storageVersion for fieldManager, a StorageVersionApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. storageVersion must be a unmodified StorageVersion API object that was retrieved from the Kubernetes API. ExtractStorageVersion provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractStorageVersionFrom

func ExtractStorageVersionFrom(storageVersion *apiserverinternalv1alpha1.StorageVersion, fieldManager string, subresource string) (*StorageVersionApplyConfiguration, error)

ExtractStorageVersionFrom extracts the applied configuration owned by fieldManager from storageVersion for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. storageVersion must be a unmodified StorageVersion API object that was retrieved from the Kubernetes API. ExtractStorageVersionFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractStorageVersionStatus

func ExtractStorageVersionStatus(storageVersion *apiserverinternalv1alpha1.StorageVersion, fieldManager string) (*StorageVersionApplyConfiguration, error)

ExtractStorageVersionStatus extracts the applied configuration owned by fieldManager from storageVersion for the status subresource.

func StorageVersion

func StorageVersion(name string) *StorageVersionApplyConfiguration

StorageVersion constructs a declarative configuration of the StorageVersion type for use with apply.

func (*StorageVersionApplyConfiguration) GetAPIVersion

func (b *StorageVersionApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*StorageVersionApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*StorageVersionApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*StorageVersionApplyConfiguration) GetNamespace

func (b *StorageVersionApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (StorageVersionApplyConfiguration) IsApplyConfiguration

func (b StorageVersionApplyConfiguration) IsApplyConfiguration()

func (*StorageVersionApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*StorageVersionApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *StorageVersionApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *StorageVersionApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*StorageVersionApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*StorageVersionApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*StorageVersionApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*StorageVersionApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type StorageVersionConditionApplyConfiguration

type StorageVersionConditionApplyConfiguration struct {
	// type of the condition.
	Type *apiserverinternalv1alpha1.StorageVersionConditionType `json:"type,omitempty"`
	// status of the condition, one of True, False, Unknown.
	Status *apiserverinternalv1alpha1.ConditionStatus `json:"status,omitempty"`
	// observedGeneration represents the .metadata.generation that the condition was set based upon, if field is set.
	ObservedGeneration *int64 `json:"observedGeneration,omitempty"`
	// lastTransitionTime is the last time the condition transitioned from one status to another.
	LastTransitionTime *v1.Time `json:"lastTransitionTime,omitempty"`
	// reason for the condition's last transition.
	Reason *string `json:"reason,omitempty"`
	// message is a human readable string indicating details about the transition.
	Message *string `json:"message,omitempty"`
}

StorageVersionConditionApplyConfiguration represents a declarative configuration of the StorageVersionCondition type for use with apply.

Describes the state of the storageVersion at a certain point.

func StorageVersionCondition

func StorageVersionCondition() *StorageVersionConditionApplyConfiguration

StorageVersionConditionApplyConfiguration constructs a declarative configuration of the StorageVersionCondition type for use with apply.

func (*StorageVersionConditionApplyConfiguration) WithLastTransitionTime

WithLastTransitionTime sets the LastTransitionTime field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the LastTransitionTime field is set to the value of the last call.

func (*StorageVersionConditionApplyConfiguration) WithMessage

WithMessage sets the Message field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Message field is set to the value of the last call.

func (*StorageVersionConditionApplyConfiguration) WithObservedGeneration

WithObservedGeneration sets the ObservedGeneration field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ObservedGeneration field is set to the value of the last call.

func (*StorageVersionConditionApplyConfiguration) WithReason

WithReason sets the Reason field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Reason field is set to the value of the last call.

func (*StorageVersionConditionApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*StorageVersionConditionApplyConfiguration) WithType

WithType sets the Type field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Type field is set to the value of the last call.

type StorageVersionStatusApplyConfiguration

type StorageVersionStatusApplyConfiguration struct {
	// storageVersions lists the reported versions per API server instance.
	StorageVersions []ServerStorageVersionApplyConfiguration `json:"storageVersions,omitempty"`
	// commonEncodingVersion is set to an encoding storage version if all API server
	// instances share that same version. If they don't share one storage version, this
	// field is left empty.
	// API servers should finish updating its storageVersionStatus entry before
	// serving write operations, so that this field will be in sync with the reality.
	CommonEncodingVersion *string `json:"commonEncodingVersion,omitempty"`
	// conditions lists the latest available observations of the storageVersion's state.
	Conditions []StorageVersionConditionApplyConfiguration `json:"conditions,omitempty"`
}

StorageVersionStatusApplyConfiguration represents a declarative configuration of the StorageVersionStatus type for use with apply.

API server instances report the versions they can decode and the version they encode objects to when persisting objects in the backend.

func StorageVersionStatus

func StorageVersionStatus() *StorageVersionStatusApplyConfiguration

StorageVersionStatusApplyConfiguration constructs a declarative configuration of the StorageVersionStatus type for use with apply.

func (*StorageVersionStatusApplyConfiguration) WithCommonEncodingVersion

WithCommonEncodingVersion sets the CommonEncodingVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CommonEncodingVersion field is set to the value of the last call.

func (*StorageVersionStatusApplyConfiguration) WithConditions

WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.

func (*StorageVersionStatusApplyConfiguration) WithStorageVersions

WithStorageVersions adds the given value to the StorageVersions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the StorageVersions field.

Source Files

serverstorageversion.go storageversion.go storageversioncondition.go storageversionstatus.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
6 packages
Last checked
2 minutes ago

Tools for package owners.