package v1beta1

import "k8s.io/client-go/applyconfigurations/batch/v1beta1"

Index

Types

type CronJobApplyConfiguration

type CronJobApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object's metadata.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Specification of the desired behavior of a cron job, including the schedule.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
	Spec *CronJobSpecApplyConfiguration `json:"spec,omitempty"`
	// Current status of a cron job.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
	Status *CronJobStatusApplyConfiguration `json:"status,omitempty"`
}

CronJobApplyConfiguration represents a declarative configuration of the CronJob type for use with apply.

CronJob represents the configuration of a single cron job.

func CronJob

func CronJob(name, namespace string) *CronJobApplyConfiguration

CronJob constructs a declarative configuration of the CronJob type for use with apply.

func ExtractCronJob

func ExtractCronJob(cronJob *batchv1beta1.CronJob, fieldManager string) (*CronJobApplyConfiguration, error)

ExtractCronJob extracts the applied configuration owned by fieldManager from cronJob. If no managedFields are found in cronJob for fieldManager, a CronJobApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. cronJob must be a unmodified CronJob API object that was retrieved from the Kubernetes API. ExtractCronJob provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractCronJobFrom

func ExtractCronJobFrom(cronJob *batchv1beta1.CronJob, fieldManager string, subresource string) (*CronJobApplyConfiguration, error)

ExtractCronJobFrom extracts the applied configuration owned by fieldManager from cronJob for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. cronJob must be a unmodified CronJob API object that was retrieved from the Kubernetes API. ExtractCronJobFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractCronJobStatus

func ExtractCronJobStatus(cronJob *batchv1beta1.CronJob, fieldManager string) (*CronJobApplyConfiguration, error)

ExtractCronJobStatus extracts the applied configuration owned by fieldManager from cronJob for the status subresource.

func (*CronJobApplyConfiguration) GetAPIVersion

func (b *CronJobApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*CronJobApplyConfiguration) GetKind

func (b *CronJobApplyConfiguration) GetKind() *string

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*CronJobApplyConfiguration) GetName

func (b *CronJobApplyConfiguration) GetName() *string

GetName retrieves the value of the Name field in the declarative configuration.

func (*CronJobApplyConfiguration) GetNamespace

func (b *CronJobApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (CronJobApplyConfiguration) IsApplyConfiguration

func (b CronJobApplyConfiguration) IsApplyConfiguration()

func (*CronJobApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithAnnotations

func (b *CronJobApplyConfiguration) WithAnnotations(entries map[string]string) *CronJobApplyConfiguration

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*CronJobApplyConfiguration) WithCreationTimestamp

func (b *CronJobApplyConfiguration) WithCreationTimestamp(value metav1.Time) *CronJobApplyConfiguration

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *CronJobApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *CronJobApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithDeletionTimestamp

func (b *CronJobApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *CronJobApplyConfiguration

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithFinalizers

func (b *CronJobApplyConfiguration) WithFinalizers(values ...string) *CronJobApplyConfiguration

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*CronJobApplyConfiguration) WithGenerateName

func (b *CronJobApplyConfiguration) WithGenerateName(value string) *CronJobApplyConfiguration

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithGeneration

func (b *CronJobApplyConfiguration) WithGeneration(value int64) *CronJobApplyConfiguration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*CronJobApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*CronJobApplyConfiguration) WithResourceVersion

func (b *CronJobApplyConfiguration) WithResourceVersion(value string) *CronJobApplyConfiguration

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*CronJobApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type CronJobSpecApplyConfiguration

type CronJobSpecApplyConfiguration struct {
	// The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron.
	Schedule *string `json:"schedule,omitempty"`
	// The time zone name for the given schedule, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones.
	// If not specified, this will default to the time zone of the kube-controller-manager process.
	// The set of valid time zone names and the time zone offset is loaded from the system-wide time zone
	// database by the API server during CronJob validation and the controller manager during execution.
	// If no system-wide time zone database can be found a bundled version of the database is used instead.
	// If the time zone name becomes invalid during the lifetime of a CronJob or due to a change in host
	// configuration, the controller will stop creating new new Jobs and will create a system event with the
	// reason UnknownTimeZone.
	// More information can be found in https://kubernetes.io/docs/concepts/workloads/controllers/cron-jobs/#time-zones
	TimeZone *string `json:"timeZone,omitempty"`
	// Optional deadline in seconds for starting the job if it misses scheduled
	// time for any reason.  Missed jobs executions will be counted as failed ones.
	StartingDeadlineSeconds *int64 `json:"startingDeadlineSeconds,omitempty"`
	// Specifies how to treat concurrent executions of a Job.
	// Valid values are:
	//
	// - "Allow" (default): allows CronJobs to run concurrently;
	// - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet;
	// - "Replace": cancels currently running job and replaces it with a new one
	ConcurrencyPolicy *batchv1beta1.ConcurrencyPolicy `json:"concurrencyPolicy,omitempty"`
	// This flag tells the controller to suspend subsequent executions, it does
	// not apply to already started executions.  Defaults to false.
	Suspend *bool `json:"suspend,omitempty"`
	// Specifies the job that will be created when executing a CronJob.
	JobTemplate *JobTemplateSpecApplyConfiguration `json:"jobTemplate,omitempty"`
	// The number of successful finished jobs to retain.
	// This is a pointer to distinguish between explicit zero and not specified.
	// Defaults to 3.
	SuccessfulJobsHistoryLimit *int32 `json:"successfulJobsHistoryLimit,omitempty"`
	// The number of failed finished jobs to retain.
	// This is a pointer to distinguish between explicit zero and not specified.
	// Defaults to 1.
	FailedJobsHistoryLimit *int32 `json:"failedJobsHistoryLimit,omitempty"`
}

CronJobSpecApplyConfiguration represents a declarative configuration of the CronJobSpec type for use with apply.

CronJobSpec describes how the job execution will look like and when it will actually run.

func CronJobSpec

func CronJobSpec() *CronJobSpecApplyConfiguration

CronJobSpecApplyConfiguration constructs a declarative configuration of the CronJobSpec type for use with apply.

func (*CronJobSpecApplyConfiguration) WithConcurrencyPolicy

WithConcurrencyPolicy sets the ConcurrencyPolicy field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ConcurrencyPolicy field is set to the value of the last call.

func (*CronJobSpecApplyConfiguration) WithFailedJobsHistoryLimit

func (b *CronJobSpecApplyConfiguration) WithFailedJobsHistoryLimit(value int32) *CronJobSpecApplyConfiguration

WithFailedJobsHistoryLimit sets the FailedJobsHistoryLimit field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the FailedJobsHistoryLimit field is set to the value of the last call.

func (*CronJobSpecApplyConfiguration) WithJobTemplate

WithJobTemplate sets the JobTemplate field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the JobTemplate field is set to the value of the last call.

func (*CronJobSpecApplyConfiguration) WithSchedule

WithSchedule sets the Schedule field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Schedule field is set to the value of the last call.

func (*CronJobSpecApplyConfiguration) WithStartingDeadlineSeconds

func (b *CronJobSpecApplyConfiguration) WithStartingDeadlineSeconds(value int64) *CronJobSpecApplyConfiguration

WithStartingDeadlineSeconds sets the StartingDeadlineSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the StartingDeadlineSeconds field is set to the value of the last call.

func (*CronJobSpecApplyConfiguration) WithSuccessfulJobsHistoryLimit

func (b *CronJobSpecApplyConfiguration) WithSuccessfulJobsHistoryLimit(value int32) *CronJobSpecApplyConfiguration

WithSuccessfulJobsHistoryLimit sets the SuccessfulJobsHistoryLimit field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the SuccessfulJobsHistoryLimit field is set to the value of the last call.

func (*CronJobSpecApplyConfiguration) WithSuspend

WithSuspend sets the Suspend field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Suspend field is set to the value of the last call.

func (*CronJobSpecApplyConfiguration) WithTimeZone

WithTimeZone sets the TimeZone field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the TimeZone field is set to the value of the last call.

type CronJobStatusApplyConfiguration

type CronJobStatusApplyConfiguration struct {
	// A list of pointers to currently running jobs.
	Active []v1.ObjectReferenceApplyConfiguration `json:"active,omitempty"`
	// Information when was the last time the job was successfully scheduled.
	LastScheduleTime *metav1.Time `json:"lastScheduleTime,omitempty"`
	// Information when was the last time the job successfully completed.
	LastSuccessfulTime *metav1.Time `json:"lastSuccessfulTime,omitempty"`
}

CronJobStatusApplyConfiguration represents a declarative configuration of the CronJobStatus type for use with apply.

CronJobStatus represents the current state of a cron job.

func CronJobStatus

func CronJobStatus() *CronJobStatusApplyConfiguration

CronJobStatusApplyConfiguration constructs a declarative configuration of the CronJobStatus type for use with apply.

func (*CronJobStatusApplyConfiguration) WithActive

WithActive adds the given value to the Active field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Active field.

func (*CronJobStatusApplyConfiguration) WithLastScheduleTime

WithLastScheduleTime sets the LastScheduleTime field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the LastScheduleTime field is set to the value of the last call.

func (*CronJobStatusApplyConfiguration) WithLastSuccessfulTime

WithLastSuccessfulTime sets the LastSuccessfulTime field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the LastSuccessfulTime field is set to the value of the last call.

type JobTemplateSpecApplyConfiguration

type JobTemplateSpecApplyConfiguration struct {
	// Standard object's metadata of the jobs created from this template.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Specification of the desired behavior of the job.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
	Spec *batchv1.JobSpecApplyConfiguration `json:"spec,omitempty"`
}

JobTemplateSpecApplyConfiguration represents a declarative configuration of the JobTemplateSpec type for use with apply.

JobTemplateSpec describes the data a Job should have when created from a template

func JobTemplateSpec

func JobTemplateSpec() *JobTemplateSpecApplyConfiguration

JobTemplateSpecApplyConfiguration constructs a declarative configuration of the JobTemplateSpec type for use with apply.

func (*JobTemplateSpecApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*JobTemplateSpecApplyConfiguration) GetNamespace

func (b *JobTemplateSpecApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (*JobTemplateSpecApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*JobTemplateSpecApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *JobTemplateSpecApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *JobTemplateSpecApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*JobTemplateSpecApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*JobTemplateSpecApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*JobTemplateSpecApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*JobTemplateSpecApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

Source Files

cronjob.go cronjobspec.go cronjobstatus.go jobtemplatespec.go

Version
v0.35.0
Published
Dec 17, 2025
Platform
linux/amd64
Imports
8 packages
Last checked
1 hour ago

Tools for package owners.