package v1

import "k8s.io/client-go/applyconfigurations/certificates/v1"

Index

Types

type CertificateSigningRequestApplyConfiguration

type CertificateSigningRequestApplyConfiguration struct {
	metav1.TypeMetaApplyConfiguration    `json:",inline"`
	*metav1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// spec contains the certificate request, and is immutable after creation.
	// Only the request, signerName, expirationSeconds, and usages fields can be set on creation.
	// Other fields are derived by Kubernetes and cannot be modified by users.
	Spec *CertificateSigningRequestSpecApplyConfiguration `json:"spec,omitempty"`
	// status contains information about whether the request is approved or denied,
	// and the certificate issued by the signer, or the failure condition indicating signer failure.
	Status *CertificateSigningRequestStatusApplyConfiguration `json:"status,omitempty"`
}

CertificateSigningRequestApplyConfiguration represents a declarative configuration of the CertificateSigningRequest type for use with apply.

CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.

Kubelets use this API to obtain: 1. client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client-kubelet" signerName). 2. serving certificates for TLS endpoints kube-apiserver can connect to securely (with the "kubernetes.io/kubelet-serving" signerName).

This API can be used to request client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client" signerName), or to obtain certificates from custom non-Kubernetes signers.

func CertificateSigningRequest

func CertificateSigningRequest(name string) *CertificateSigningRequestApplyConfiguration

CertificateSigningRequest constructs a declarative configuration of the CertificateSigningRequest type for use with apply.

func ExtractCertificateSigningRequest

func ExtractCertificateSigningRequest(certificateSigningRequest *certificatesv1.CertificateSigningRequest, fieldManager string) (*CertificateSigningRequestApplyConfiguration, error)

ExtractCertificateSigningRequest extracts the applied configuration owned by fieldManager from certificateSigningRequest. If no managedFields are found in certificateSigningRequest for fieldManager, a CertificateSigningRequestApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. certificateSigningRequest must be a unmodified CertificateSigningRequest API object that was retrieved from the Kubernetes API. ExtractCertificateSigningRequest provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractCertificateSigningRequestApproval

func ExtractCertificateSigningRequestApproval(certificateSigningRequest *certificatesv1.CertificateSigningRequest, fieldManager string) (*CertificateSigningRequestApplyConfiguration, error)

ExtractCertificateSigningRequestApproval extracts the applied configuration owned by fieldManager from certificateSigningRequest for the approval subresource.

func ExtractCertificateSigningRequestFrom

func ExtractCertificateSigningRequestFrom(certificateSigningRequest *certificatesv1.CertificateSigningRequest, fieldManager string, subresource string) (*CertificateSigningRequestApplyConfiguration, error)

ExtractCertificateSigningRequestFrom extracts the applied configuration owned by fieldManager from certificateSigningRequest for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. certificateSigningRequest must be a unmodified CertificateSigningRequest API object that was retrieved from the Kubernetes API. ExtractCertificateSigningRequestFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractCertificateSigningRequestStatus

func ExtractCertificateSigningRequestStatus(certificateSigningRequest *certificatesv1.CertificateSigningRequest, fieldManager string) (*CertificateSigningRequestApplyConfiguration, error)

ExtractCertificateSigningRequestStatus extracts the applied configuration owned by fieldManager from certificateSigningRequest for the status subresource.

func (*CertificateSigningRequestApplyConfiguration) GetAPIVersion

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*CertificateSigningRequestApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*CertificateSigningRequestApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*CertificateSigningRequestApplyConfiguration) GetNamespace

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (CertificateSigningRequestApplyConfiguration) IsApplyConfiguration

func (b CertificateSigningRequestApplyConfiguration) IsApplyConfiguration()

func (*CertificateSigningRequestApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*CertificateSigningRequestApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithDeletionGracePeriodSeconds

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*CertificateSigningRequestApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*CertificateSigningRequestApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*CertificateSigningRequestApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*CertificateSigningRequestApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type CertificateSigningRequestConditionApplyConfiguration

type CertificateSigningRequestConditionApplyConfiguration struct {
	// type of the condition. Known conditions are "Approved", "Denied", and "Failed".
	//
	// An "Approved" condition is added via the /approval subresource,
	// indicating the request was approved and should be issued by the signer.
	//
	// A "Denied" condition is added via the /approval subresource,
	// indicating the request was denied and should not be issued by the signer.
	//
	// A "Failed" condition is added via the /status subresource,
	// indicating the signer failed to issue the certificate.
	//
	// Approved and Denied conditions are mutually exclusive.
	// Approved, Denied, and Failed conditions cannot be removed once added.
	//
	// Only one condition of a given type is allowed.
	Type *certificatesv1.RequestConditionType `json:"type,omitempty"`
	// status of the condition, one of True, False, Unknown.
	// Approved, Denied, and Failed conditions may not be "False" or "Unknown".
	Status *corev1.ConditionStatus `json:"status,omitempty"`
	// reason indicates a brief reason for the request state
	Reason *string `json:"reason,omitempty"`
	// message contains a human readable message with details about the request state
	Message *string `json:"message,omitempty"`
	// lastUpdateTime is the time of the last update to this condition
	LastUpdateTime *metav1.Time `json:"lastUpdateTime,omitempty"`
	// lastTransitionTime is the time the condition last transitioned from one status to another.
	// If unset, when a new condition type is added or an existing condition's status is changed,
	// the server defaults this to the current time.
	LastTransitionTime *metav1.Time `json:"lastTransitionTime,omitempty"`
}

CertificateSigningRequestConditionApplyConfiguration represents a declarative configuration of the CertificateSigningRequestCondition type for use with apply.

CertificateSigningRequestCondition describes a condition of a CertificateSigningRequest object

func CertificateSigningRequestCondition

func CertificateSigningRequestCondition() *CertificateSigningRequestConditionApplyConfiguration

CertificateSigningRequestConditionApplyConfiguration constructs a declarative configuration of the CertificateSigningRequestCondition type for use with apply.

func (*CertificateSigningRequestConditionApplyConfiguration) WithLastTransitionTime

WithLastTransitionTime sets the LastTransitionTime field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the LastTransitionTime field is set to the value of the last call.

func (*CertificateSigningRequestConditionApplyConfiguration) WithLastUpdateTime

WithLastUpdateTime sets the LastUpdateTime field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the LastUpdateTime field is set to the value of the last call.

func (*CertificateSigningRequestConditionApplyConfiguration) WithMessage

WithMessage sets the Message field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Message field is set to the value of the last call.

func (*CertificateSigningRequestConditionApplyConfiguration) WithReason

WithReason sets the Reason field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Reason field is set to the value of the last call.

func (*CertificateSigningRequestConditionApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*CertificateSigningRequestConditionApplyConfiguration) WithType

WithType sets the Type field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Type field is set to the value of the last call.

type CertificateSigningRequestSpecApplyConfiguration

type CertificateSigningRequestSpecApplyConfiguration struct {
	// request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block.
	// When serialized as JSON or YAML, the data is additionally base64-encoded.
	Request []byte `json:"request,omitempty"`
	// signerName indicates the requested signer, and is a qualified name.
	//
	// List/watch requests for CertificateSigningRequests can filter on this field using a "spec.signerName=NAME" fieldSelector.
	//
	// Well-known Kubernetes signers are:
	// 1. "kubernetes.io/kube-apiserver-client": issues client certificates that can be used to authenticate to kube-apiserver.
	// Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the "csrsigning" controller in kube-controller-manager.
	// 2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates that kubelets use to authenticate to kube-apiserver.
	// Requests for this signer can be auto-approved by the "csrapproving" controller in kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
	// 3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.
	// Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
	//
	// More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers
	//
	// Custom signerNames can also be specified. The signer defines:
	// 1. Trust distribution: how trust (CA bundles) are distributed.
	// 2. Permitted subjects: and behavior when a disallowed subject is requested.
	// 3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.
	// 4. Required, permitted, or forbidden key usages / extended key usages.
	// 5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.
	// 6. Whether or not requests for CA certificates are allowed.
	SignerName *string `json:"signerName,omitempty"`
	// expirationSeconds is the requested duration of validity of the issued
	// certificate. The certificate signer may issue a certificate with a different
	// validity duration so a client must check the delta between the notBefore and
	// and notAfter fields in the issued certificate to determine the actual duration.
	//
	// The v1.22+ in-tree implementations of the well-known Kubernetes signers will
	// honor this field as long as the requested duration is not greater than the
	// maximum duration they will honor per the --cluster-signing-duration CLI
	// flag to the Kubernetes controller manager.
	//
	// Certificate signers may not honor this field for various reasons:
	//
	// 1. Old signer that is unaware of the field (such as the in-tree
	// implementations prior to v1.22)
	// 2. Signer whose configured maximum is shorter than the requested duration
	// 3. Signer whose configured minimum is longer than the requested duration
	//
	// The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.
	ExpirationSeconds *int32 `json:"expirationSeconds,omitempty"`
	// usages specifies a set of key usages requested in the issued certificate.
	//
	// Requests for TLS client certificates typically request: "digital signature", "key encipherment", "client auth".
	//
	// Requests for TLS serving certificates typically request: "key encipherment", "digital signature", "server auth".
	//
	// Valid values are:
	// "signing", "digital signature", "content commitment",
	// "key encipherment", "key agreement", "data encipherment",
	// "cert sign", "crl sign", "encipher only", "decipher only", "any",
	// "server auth", "client auth",
	// "code signing", "email protection", "s/mime",
	// "ipsec end system", "ipsec tunnel", "ipsec user",
	// "timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"
	Usages []certificatesv1.KeyUsage `json:"usages,omitempty"`
	// username contains the name of the user that created the CertificateSigningRequest.
	// Populated by the API server on creation and immutable.
	Username *string `json:"username,omitempty"`
	// uid contains the uid of the user that created the CertificateSigningRequest.
	// Populated by the API server on creation and immutable.
	UID *string `json:"uid,omitempty"`
	// groups contains group membership of the user that created the CertificateSigningRequest.
	// Populated by the API server on creation and immutable.
	Groups []string `json:"groups,omitempty"`
	// extra contains extra attributes of the user that created the CertificateSigningRequest.
	// Populated by the API server on creation and immutable.
	Extra map[string]certificatesv1.ExtraValue `json:"extra,omitempty"`
}

CertificateSigningRequestSpecApplyConfiguration represents a declarative configuration of the CertificateSigningRequestSpec type for use with apply.

CertificateSigningRequestSpec contains the certificate request.

func CertificateSigningRequestSpec

func CertificateSigningRequestSpec() *CertificateSigningRequestSpecApplyConfiguration

CertificateSigningRequestSpecApplyConfiguration constructs a declarative configuration of the CertificateSigningRequestSpec type for use with apply.

func (*CertificateSigningRequestSpecApplyConfiguration) WithExpirationSeconds

WithExpirationSeconds sets the ExpirationSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ExpirationSeconds field is set to the value of the last call.

func (*CertificateSigningRequestSpecApplyConfiguration) WithExtra

WithExtra puts the entries into the Extra field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Extra field, overwriting an existing map entries in Extra field with the same key.

func (*CertificateSigningRequestSpecApplyConfiguration) WithGroups

WithGroups adds the given value to the Groups field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Groups field.

func (*CertificateSigningRequestSpecApplyConfiguration) WithRequest

WithRequest adds the given value to the Request field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Request field.

func (*CertificateSigningRequestSpecApplyConfiguration) WithSignerName

WithSignerName sets the SignerName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the SignerName field is set to the value of the last call.

func (*CertificateSigningRequestSpecApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

func (*CertificateSigningRequestSpecApplyConfiguration) WithUsages

WithUsages adds the given value to the Usages field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Usages field.

func (*CertificateSigningRequestSpecApplyConfiguration) WithUsername

WithUsername sets the Username field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Username field is set to the value of the last call.

type CertificateSigningRequestStatusApplyConfiguration

type CertificateSigningRequestStatusApplyConfiguration struct {
	// conditions applied to the request. Known conditions are "Approved", "Denied", and "Failed".
	Conditions []CertificateSigningRequestConditionApplyConfiguration `json:"conditions,omitempty"`
	// certificate is populated with an issued certificate by the signer after an Approved condition is present.
	// This field is set via the /status subresource. Once populated, this field is immutable.
	//
	// If the certificate signing request is denied, a condition of type "Denied" is added and this field remains empty.
	// If the signer cannot issue the certificate, a condition of type "Failed" is added and this field remains empty.
	//
	// Validation requirements:
	// 1. certificate must contain one or more PEM blocks.
	// 2. All PEM blocks must have the "CERTIFICATE" label, contain no headers, and the encoded data
	// must be a BER-encoded ASN.1 Certificate structure as described in section 4 of RFC5280.
	// 3. Non-PEM content may appear before or after the "CERTIFICATE" PEM blocks and is unvalidated,
	// to allow for explanatory text as described in section 5.2 of RFC7468.
	//
	// If more than one PEM block is present, and the definition of the requested spec.signerName
	// does not indicate otherwise, the first block is the issued certificate,
	// and subsequent blocks should be treated as intermediate certificates and presented in TLS handshakes.
	//
	// The certificate is encoded in PEM format.
	//
	// When serialized as JSON or YAML, the data is additionally base64-encoded, so it consists of:
	//
	// base64(
	// -----BEGIN CERTIFICATE-----
	// ...
	// -----END CERTIFICATE-----
	// )
	Certificate []byte `json:"certificate,omitempty"`
}

CertificateSigningRequestStatusApplyConfiguration represents a declarative configuration of the CertificateSigningRequestStatus type for use with apply.

CertificateSigningRequestStatus contains conditions used to indicate approved/denied/failed status of the request, and the issued certificate.

func CertificateSigningRequestStatus

func CertificateSigningRequestStatus() *CertificateSigningRequestStatusApplyConfiguration

CertificateSigningRequestStatusApplyConfiguration constructs a declarative configuration of the CertificateSigningRequestStatus type for use with apply.

func (*CertificateSigningRequestStatusApplyConfiguration) WithCertificate

WithCertificate adds the given value to the Certificate field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Certificate field.

func (*CertificateSigningRequestStatusApplyConfiguration) WithConditions

WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.

Source Files

certificatesigningrequest.go certificatesigningrequestcondition.go certificatesigningrequestspec.go certificatesigningrequeststatus.go

Version
v0.35.2
Published
Feb 27, 2026
Platform
linux/amd64
Imports
7 packages
Last checked
12 minutes ago

Tools for package owners.