package v1alpha1

import "k8s.io/client-go/applyconfigurations/certificates/v1alpha1"

Index

Types

type ClusterTrustBundleApplyConfiguration

type ClusterTrustBundleApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// metadata contains the object metadata.
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// spec contains the signer (if any) and trust anchors.
	Spec *ClusterTrustBundleSpecApplyConfiguration `json:"spec,omitempty"`
}

ClusterTrustBundleApplyConfiguration represents a declarative configuration of the ClusterTrustBundle type for use with apply.

ClusterTrustBundle is a cluster-scoped container for X.509 trust anchors (root certificates).

ClusterTrustBundle objects are considered to be readable by any authenticated user in the cluster, because they can be mounted by pods using the `clusterTrustBundle` projection. All service accounts have read access to ClusterTrustBundles by default. Users who only have namespace-level access to a cluster can read ClusterTrustBundles by impersonating a serviceaccount that they have access to.

It can be optionally associated with a particular assigner, in which case it contains one valid set of trust anchors for that signer. Signers may have multiple associated ClusterTrustBundles; each is an independent set of trust anchors for that signer. Admission control is used to enforce that only users with permissions on the signer can create or modify the corresponding bundle.

func ClusterTrustBundle

func ClusterTrustBundle(name string) *ClusterTrustBundleApplyConfiguration

ClusterTrustBundle constructs a declarative configuration of the ClusterTrustBundle type for use with apply.

func ExtractClusterTrustBundle

func ExtractClusterTrustBundle(clusterTrustBundle *certificatesv1alpha1.ClusterTrustBundle, fieldManager string) (*ClusterTrustBundleApplyConfiguration, error)

ExtractClusterTrustBundle extracts the applied configuration owned by fieldManager from clusterTrustBundle. If no managedFields are found in clusterTrustBundle for fieldManager, a ClusterTrustBundleApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. clusterTrustBundle must be a unmodified ClusterTrustBundle API object that was retrieved from the Kubernetes API. ExtractClusterTrustBundle provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractClusterTrustBundleFrom

func ExtractClusterTrustBundleFrom(clusterTrustBundle *certificatesv1alpha1.ClusterTrustBundle, fieldManager string, subresource string) (*ClusterTrustBundleApplyConfiguration, error)

ExtractClusterTrustBundleFrom extracts the applied configuration owned by fieldManager from clusterTrustBundle for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. clusterTrustBundle must be a unmodified ClusterTrustBundle API object that was retrieved from the Kubernetes API. ExtractClusterTrustBundleFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func (*ClusterTrustBundleApplyConfiguration) GetAPIVersion

func (b *ClusterTrustBundleApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*ClusterTrustBundleApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*ClusterTrustBundleApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*ClusterTrustBundleApplyConfiguration) GetNamespace

func (b *ClusterTrustBundleApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (ClusterTrustBundleApplyConfiguration) IsApplyConfiguration

func (b ClusterTrustBundleApplyConfiguration) IsApplyConfiguration()

func (*ClusterTrustBundleApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*ClusterTrustBundleApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *ClusterTrustBundleApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ClusterTrustBundleApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*ClusterTrustBundleApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*ClusterTrustBundleApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*ClusterTrustBundleApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*ClusterTrustBundleApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type ClusterTrustBundleSpecApplyConfiguration

type ClusterTrustBundleSpecApplyConfiguration struct {
	// signerName indicates the associated signer, if any.
	//
	// In order to create or update a ClusterTrustBundle that sets signerName,
	// you must have the following cluster-scoped permission:
	// group=certificates.k8s.io resource=signers resourceName=<the signer name>
	// verb=attest.
	//
	// If signerName is not empty, then the ClusterTrustBundle object must be
	// named with the signer name as a prefix (translating slashes to colons).
	// For example, for the signer name `example.com/foo`, valid
	// ClusterTrustBundle object names include `example.com:foo:abc` and
	// `example.com:foo:v1`.
	//
	// If signerName is empty, then the ClusterTrustBundle object's name must
	// not have such a prefix.
	//
	// List/watch requests for ClusterTrustBundles can filter on this field
	// using a `spec.signerName=NAME` field selector.
	SignerName *string `json:"signerName,omitempty"`
	// trustBundle contains the individual X.509 trust anchors for this
	// bundle, as PEM bundle of PEM-wrapped, DER-formatted X.509 certificates.
	//
	// The data must consist only of PEM certificate blocks that parse as valid
	// X.509 certificates.  Each certificate must include a basic constraints
	// extension with the CA bit set.  The API server will reject objects that
	// contain duplicate certificates, or that use PEM block headers.
	//
	// Users of ClusterTrustBundles, including Kubelet, are free to reorder and
	// deduplicate certificate blocks in this file according to their own logic,
	// as well as to drop PEM block headers and inter-block data.
	TrustBundle *string `json:"trustBundle,omitempty"`
}

ClusterTrustBundleSpecApplyConfiguration represents a declarative configuration of the ClusterTrustBundleSpec type for use with apply.

ClusterTrustBundleSpec contains the signer and trust anchors.

func ClusterTrustBundleSpec

func ClusterTrustBundleSpec() *ClusterTrustBundleSpecApplyConfiguration

ClusterTrustBundleSpecApplyConfiguration constructs a declarative configuration of the ClusterTrustBundleSpec type for use with apply.

func (*ClusterTrustBundleSpecApplyConfiguration) WithSignerName

WithSignerName sets the SignerName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the SignerName field is set to the value of the last call.

func (*ClusterTrustBundleSpecApplyConfiguration) WithTrustBundle

WithTrustBundle sets the TrustBundle field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the TrustBundle field is set to the value of the last call.

Source Files

clustertrustbundle.go clustertrustbundlespec.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
6 packages
Last checked
2 minutes ago

Tools for package owners.