package v1alpha2
import "k8s.io/client-go/applyconfigurations/coordination/v1alpha2"
Index ¶
- type LeaseCandidateApplyConfiguration
- func ExtractLeaseCandidate(leaseCandidate *coordinationv1alpha2.LeaseCandidate, fieldManager string) (*LeaseCandidateApplyConfiguration, error)
- func ExtractLeaseCandidateFrom(leaseCandidate *coordinationv1alpha2.LeaseCandidate, fieldManager string, subresource string) (*LeaseCandidateApplyConfiguration, error)
- func LeaseCandidate(name, namespace string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) GetAPIVersion() *string
- func (b *LeaseCandidateApplyConfiguration) GetKind() *string
- func (b *LeaseCandidateApplyConfiguration) GetName() *string
- func (b *LeaseCandidateApplyConfiguration) GetNamespace() *string
- func (b LeaseCandidateApplyConfiguration) IsApplyConfiguration()
- func (b *LeaseCandidateApplyConfiguration) WithAPIVersion(value string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithAnnotations(entries map[string]string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithCreationTimestamp(value metav1.Time) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithFinalizers(values ...string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithGenerateName(value string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithGeneration(value int64) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithKind(value string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithLabels(entries map[string]string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithName(value string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithNamespace(value string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithResourceVersion(value string) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithSpec(value *LeaseCandidateSpecApplyConfiguration) *LeaseCandidateApplyConfiguration
- func (b *LeaseCandidateApplyConfiguration) WithUID(value types.UID) *LeaseCandidateApplyConfiguration
- type LeaseCandidateSpecApplyConfiguration
- func LeaseCandidateSpec() *LeaseCandidateSpecApplyConfiguration
- func (b *LeaseCandidateSpecApplyConfiguration) WithBinaryVersion(value string) *LeaseCandidateSpecApplyConfiguration
- func (b *LeaseCandidateSpecApplyConfiguration) WithEmulationVersion(value string) *LeaseCandidateSpecApplyConfiguration
- func (b *LeaseCandidateSpecApplyConfiguration) WithLeaseName(value string) *LeaseCandidateSpecApplyConfiguration
- func (b *LeaseCandidateSpecApplyConfiguration) WithPingTime(value v1.MicroTime) *LeaseCandidateSpecApplyConfiguration
- func (b *LeaseCandidateSpecApplyConfiguration) WithRenewTime(value v1.MicroTime) *LeaseCandidateSpecApplyConfiguration
- func (b *LeaseCandidateSpecApplyConfiguration) WithStrategy(value coordinationv1.CoordinatedLeaseStrategy) *LeaseCandidateSpecApplyConfiguration
Types ¶
type LeaseCandidateApplyConfiguration ¶
type LeaseCandidateApplyConfiguration struct {
v1.TypeMetaApplyConfiguration `json:",inline"`
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
// spec contains the specification of the Lease.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
Spec *LeaseCandidateSpecApplyConfiguration `json:"spec,omitempty"`
}
LeaseCandidateApplyConfiguration represents a declarative configuration of the LeaseCandidate type for use with apply.
LeaseCandidate defines a candidate for a Lease object. Candidates are created such that coordinated leader election will pick the best leader from the list of candidates.
func ExtractLeaseCandidate ¶
func ExtractLeaseCandidate(leaseCandidate *coordinationv1alpha2.LeaseCandidate, fieldManager string) (*LeaseCandidateApplyConfiguration, error)
ExtractLeaseCandidate extracts the applied configuration owned by fieldManager from leaseCandidate. If no managedFields are found in leaseCandidate for fieldManager, a LeaseCandidateApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. leaseCandidate must be a unmodified LeaseCandidate API object that was retrieved from the Kubernetes API. ExtractLeaseCandidate provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractLeaseCandidateFrom ¶
func ExtractLeaseCandidateFrom(leaseCandidate *coordinationv1alpha2.LeaseCandidate, fieldManager string, subresource string) (*LeaseCandidateApplyConfiguration, error)
ExtractLeaseCandidateFrom extracts the applied configuration owned by fieldManager from leaseCandidate for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. leaseCandidate must be a unmodified LeaseCandidate API object that was retrieved from the Kubernetes API. ExtractLeaseCandidateFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func LeaseCandidate ¶
func LeaseCandidate(name, namespace string) *LeaseCandidateApplyConfiguration
LeaseCandidate constructs a declarative configuration of the LeaseCandidate type for use with apply.
func (*LeaseCandidateApplyConfiguration) GetAPIVersion ¶
func (b *LeaseCandidateApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*LeaseCandidateApplyConfiguration) GetKind ¶
func (b *LeaseCandidateApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*LeaseCandidateApplyConfiguration) GetName ¶
func (b *LeaseCandidateApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*LeaseCandidateApplyConfiguration) GetNamespace ¶
func (b *LeaseCandidateApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (LeaseCandidateApplyConfiguration) IsApplyConfiguration ¶
func (b LeaseCandidateApplyConfiguration) IsApplyConfiguration()
func (*LeaseCandidateApplyConfiguration) WithAPIVersion ¶
func (b *LeaseCandidateApplyConfiguration) WithAPIVersion(value string) *LeaseCandidateApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithAnnotations ¶
func (b *LeaseCandidateApplyConfiguration) WithAnnotations(entries map[string]string) *LeaseCandidateApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*LeaseCandidateApplyConfiguration) WithCreationTimestamp ¶
func (b *LeaseCandidateApplyConfiguration) WithCreationTimestamp(value metav1.Time) *LeaseCandidateApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *LeaseCandidateApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *LeaseCandidateApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithDeletionTimestamp ¶
func (b *LeaseCandidateApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *LeaseCandidateApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithFinalizers ¶
func (b *LeaseCandidateApplyConfiguration) WithFinalizers(values ...string) *LeaseCandidateApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*LeaseCandidateApplyConfiguration) WithGenerateName ¶
func (b *LeaseCandidateApplyConfiguration) WithGenerateName(value string) *LeaseCandidateApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithGeneration ¶
func (b *LeaseCandidateApplyConfiguration) WithGeneration(value int64) *LeaseCandidateApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithKind ¶
func (b *LeaseCandidateApplyConfiguration) WithKind(value string) *LeaseCandidateApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithLabels ¶
func (b *LeaseCandidateApplyConfiguration) WithLabels(entries map[string]string) *LeaseCandidateApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*LeaseCandidateApplyConfiguration) WithName ¶
func (b *LeaseCandidateApplyConfiguration) WithName(value string) *LeaseCandidateApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithNamespace ¶
func (b *LeaseCandidateApplyConfiguration) WithNamespace(value string) *LeaseCandidateApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithOwnerReferences ¶
func (b *LeaseCandidateApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *LeaseCandidateApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*LeaseCandidateApplyConfiguration) WithResourceVersion ¶
func (b *LeaseCandidateApplyConfiguration) WithResourceVersion(value string) *LeaseCandidateApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithSpec ¶
func (b *LeaseCandidateApplyConfiguration) WithSpec(value *LeaseCandidateSpecApplyConfiguration) *LeaseCandidateApplyConfiguration
WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.
func (*LeaseCandidateApplyConfiguration) WithUID ¶
func (b *LeaseCandidateApplyConfiguration) WithUID(value types.UID) *LeaseCandidateApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type LeaseCandidateSpecApplyConfiguration ¶
type LeaseCandidateSpecApplyConfiguration struct {
// LeaseName is the name of the lease for which this candidate is contending.
// This field is immutable.
LeaseName *string `json:"leaseName,omitempty"`
// PingTime is the last time that the server has requested the LeaseCandidate
// to renew. It is only done during leader election to check if any
// LeaseCandidates have become ineligible. When PingTime is updated, the
// LeaseCandidate will respond by updating RenewTime.
PingTime *v1.MicroTime `json:"pingTime,omitempty"`
// RenewTime is the time that the LeaseCandidate was last updated.
// Any time a Lease needs to do leader election, the PingTime field
// is updated to signal to the LeaseCandidate that they should update
// the RenewTime.
// Old LeaseCandidate objects are also garbage collected if it has been hours
// since the last renew. The PingTime field is updated regularly to prevent
// garbage collection for still active LeaseCandidates.
RenewTime *v1.MicroTime `json:"renewTime,omitempty"`
// BinaryVersion is the binary version. It must be in a semver format without leading `v`.
// This field is required.
BinaryVersion *string `json:"binaryVersion,omitempty"`
// EmulationVersion is the emulation version. It must be in a semver format without leading `v`.
// EmulationVersion must be less than or equal to BinaryVersion.
// This field is required when strategy is "OldestEmulationVersion"
EmulationVersion *string `json:"emulationVersion,omitempty"`
// Strategy is the strategy that coordinated leader election will use for picking the leader.
// If multiple candidates for the same Lease return different strategies, the strategy provided
// by the candidate with the latest BinaryVersion will be used. If there is still conflict,
// this is a user error and coordinated leader election will not operate the Lease until resolved.
Strategy *coordinationv1.CoordinatedLeaseStrategy `json:"strategy,omitempty"`
}
LeaseCandidateSpecApplyConfiguration represents a declarative configuration of the LeaseCandidateSpec type for use with apply.
LeaseCandidateSpec is a specification of a Lease.
func LeaseCandidateSpec ¶
func LeaseCandidateSpec() *LeaseCandidateSpecApplyConfiguration
LeaseCandidateSpecApplyConfiguration constructs a declarative configuration of the LeaseCandidateSpec type for use with apply.
func (*LeaseCandidateSpecApplyConfiguration) WithBinaryVersion ¶
func (b *LeaseCandidateSpecApplyConfiguration) WithBinaryVersion(value string) *LeaseCandidateSpecApplyConfiguration
WithBinaryVersion sets the BinaryVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the BinaryVersion field is set to the value of the last call.
func (*LeaseCandidateSpecApplyConfiguration) WithEmulationVersion ¶
func (b *LeaseCandidateSpecApplyConfiguration) WithEmulationVersion(value string) *LeaseCandidateSpecApplyConfiguration
WithEmulationVersion sets the EmulationVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the EmulationVersion field is set to the value of the last call.
func (*LeaseCandidateSpecApplyConfiguration) WithLeaseName ¶
func (b *LeaseCandidateSpecApplyConfiguration) WithLeaseName(value string) *LeaseCandidateSpecApplyConfiguration
WithLeaseName sets the LeaseName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the LeaseName field is set to the value of the last call.
func (*LeaseCandidateSpecApplyConfiguration) WithPingTime ¶
func (b *LeaseCandidateSpecApplyConfiguration) WithPingTime(value v1.MicroTime) *LeaseCandidateSpecApplyConfiguration
WithPingTime sets the PingTime field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the PingTime field is set to the value of the last call.
func (*LeaseCandidateSpecApplyConfiguration) WithRenewTime ¶
func (b *LeaseCandidateSpecApplyConfiguration) WithRenewTime(value v1.MicroTime) *LeaseCandidateSpecApplyConfiguration
WithRenewTime sets the RenewTime field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the RenewTime field is set to the value of the last call.
func (*LeaseCandidateSpecApplyConfiguration) WithStrategy ¶
func (b *LeaseCandidateSpecApplyConfiguration) WithStrategy(value coordinationv1.CoordinatedLeaseStrategy) *LeaseCandidateSpecApplyConfiguration
WithStrategy sets the Strategy field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Strategy field is set to the value of the last call.
Source Files ¶
leasecandidate.go leasecandidatespec.go
- Version
- v0.35.3
- Published
- Mar 19, 2026
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 10 minutes ago –
Tools for package owners.