Documentation
¶
Index ¶
- type OverheadApplyConfiguration
- type RuntimeClassApplyConfiguration
- func ExtractRuntimeClass(runtimeClass *nodev1.RuntimeClass, fieldManager string) (*RuntimeClassApplyConfiguration, error)
- func ExtractRuntimeClassFrom(runtimeClass *nodev1.RuntimeClass, fieldManager string, subresource string) (*RuntimeClassApplyConfiguration, error)
- func RuntimeClass(name string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) GetAPIVersion() *string
- func (b *RuntimeClassApplyConfiguration) GetKind() *string
- func (b *RuntimeClassApplyConfiguration) GetName() *string
- func (b *RuntimeClassApplyConfiguration) GetNamespace() *string
- func (b RuntimeClassApplyConfiguration) IsApplyConfiguration()
- func (b *RuntimeClassApplyConfiguration) WithAPIVersion(value string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithAnnotations(entries map[string]string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithCreationTimestamp(value apismetav1.Time) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithDeletionTimestamp(value apismetav1.Time) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithFinalizers(values ...string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithGenerateName(value string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithGeneration(value int64) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithHandler(value string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithKind(value string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithLabels(entries map[string]string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithName(value string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithNamespace(value string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithOverhead(value *OverheadApplyConfiguration) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithOwnerReferences(values ...*metav1.OwnerReferenceApplyConfiguration) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithResourceVersion(value string) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithScheduling(value *SchedulingApplyConfiguration) *RuntimeClassApplyConfiguration
- func (b *RuntimeClassApplyConfiguration) WithUID(value types.UID) *RuntimeClassApplyConfiguration
- type SchedulingApplyConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type OverheadApplyConfiguration ¶
type OverheadApplyConfiguration struct {
// podFixed represents the fixed resource overhead associated with running a pod.
PodFixed *corev1.ResourceList `json:"podFixed,omitempty"`
}
OverheadApplyConfiguration represents a declarative configuration of the Overhead type for use with apply.
Overhead structure represents the resource overhead associated with running a pod.
func Overhead ¶
func Overhead() *OverheadApplyConfiguration
OverheadApplyConfiguration constructs a declarative configuration of the Overhead type for use with apply.
func (*OverheadApplyConfiguration) WithPodFixed ¶
func (b *OverheadApplyConfiguration) WithPodFixed(value corev1.ResourceList) *OverheadApplyConfiguration
WithPodFixed sets the PodFixed field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the PodFixed field is set to the value of the last call.
type RuntimeClassApplyConfiguration ¶
type RuntimeClassApplyConfiguration struct {
metav1.TypeMetaApplyConfiguration `json:",inline"`
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
*metav1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
// handler specifies the underlying runtime and configuration that the CRI
// implementation will use to handle pods of this class. The possible values
// are specific to the node & CRI configuration. It is assumed that all
// handlers are available on every node, and handlers of the same name are
// equivalent on every node.
// For example, a handler called "runc" might specify that the runc OCI
// runtime (using native Linux containers) will be used to run the containers
// in a pod.
// The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements,
// and is immutable.
Handler *string `json:"handler,omitempty"`
// overhead represents the resource overhead associated with running a pod for a
// given RuntimeClass. For more details, see
// https://kubernetes.io/docs/concepts/scheduling-eviction/pod-overhead/
Overhead *OverheadApplyConfiguration `json:"overhead,omitempty"`
// scheduling holds the scheduling constraints to ensure that pods running
// with this RuntimeClass are scheduled to nodes that support it.
// If scheduling is nil, this RuntimeClass is assumed to be supported by all
// nodes.
Scheduling *SchedulingApplyConfiguration `json:"scheduling,omitempty"`
}
RuntimeClassApplyConfiguration represents a declarative configuration of the RuntimeClass type for use with apply.
RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod. For more details, see https://kubernetes.io/docs/concepts/containers/runtime-class/
func ExtractRuntimeClass ¶
func ExtractRuntimeClass(runtimeClass *nodev1.RuntimeClass, fieldManager string) (*RuntimeClassApplyConfiguration, error)
ExtractRuntimeClass extracts the applied configuration owned by fieldManager from runtimeClass. If no managedFields are found in runtimeClass for fieldManager, a RuntimeClassApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. runtimeClass must be a unmodified RuntimeClass API object that was retrieved from the Kubernetes API. ExtractRuntimeClass provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractRuntimeClassFrom ¶ added in v0.35.0
func ExtractRuntimeClassFrom(runtimeClass *nodev1.RuntimeClass, fieldManager string, subresource string) (*RuntimeClassApplyConfiguration, error)
ExtractRuntimeClassFrom extracts the applied configuration owned by fieldManager from runtimeClass for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. runtimeClass must be a unmodified RuntimeClass API object that was retrieved from the Kubernetes API. ExtractRuntimeClassFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func RuntimeClass ¶
func RuntimeClass(name string) *RuntimeClassApplyConfiguration
RuntimeClass constructs a declarative configuration of the RuntimeClass type for use with apply.
func (*RuntimeClassApplyConfiguration) GetAPIVersion ¶ added in v0.34.0
func (b *RuntimeClassApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*RuntimeClassApplyConfiguration) GetKind ¶ added in v0.34.0
func (b *RuntimeClassApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*RuntimeClassApplyConfiguration) GetName ¶ added in v0.31.0
func (b *RuntimeClassApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*RuntimeClassApplyConfiguration) GetNamespace ¶ added in v0.34.0
func (b *RuntimeClassApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (RuntimeClassApplyConfiguration) IsApplyConfiguration ¶ added in v0.34.0
func (b RuntimeClassApplyConfiguration) IsApplyConfiguration()
func (*RuntimeClassApplyConfiguration) WithAPIVersion ¶
func (b *RuntimeClassApplyConfiguration) WithAPIVersion(value string) *RuntimeClassApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithAnnotations ¶
func (b *RuntimeClassApplyConfiguration) WithAnnotations(entries map[string]string) *RuntimeClassApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*RuntimeClassApplyConfiguration) WithCreationTimestamp ¶
func (b *RuntimeClassApplyConfiguration) WithCreationTimestamp(value apismetav1.Time) *RuntimeClassApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *RuntimeClassApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *RuntimeClassApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithDeletionTimestamp ¶
func (b *RuntimeClassApplyConfiguration) WithDeletionTimestamp(value apismetav1.Time) *RuntimeClassApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithFinalizers ¶
func (b *RuntimeClassApplyConfiguration) WithFinalizers(values ...string) *RuntimeClassApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*RuntimeClassApplyConfiguration) WithGenerateName ¶
func (b *RuntimeClassApplyConfiguration) WithGenerateName(value string) *RuntimeClassApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithGeneration ¶
func (b *RuntimeClassApplyConfiguration) WithGeneration(value int64) *RuntimeClassApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithHandler ¶
func (b *RuntimeClassApplyConfiguration) WithHandler(value string) *RuntimeClassApplyConfiguration
WithHandler sets the Handler field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Handler field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithKind ¶
func (b *RuntimeClassApplyConfiguration) WithKind(value string) *RuntimeClassApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithLabels ¶
func (b *RuntimeClassApplyConfiguration) WithLabels(entries map[string]string) *RuntimeClassApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*RuntimeClassApplyConfiguration) WithName ¶
func (b *RuntimeClassApplyConfiguration) WithName(value string) *RuntimeClassApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithNamespace ¶
func (b *RuntimeClassApplyConfiguration) WithNamespace(value string) *RuntimeClassApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithOverhead ¶
func (b *RuntimeClassApplyConfiguration) WithOverhead(value *OverheadApplyConfiguration) *RuntimeClassApplyConfiguration
WithOverhead sets the Overhead field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Overhead field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithOwnerReferences ¶
func (b *RuntimeClassApplyConfiguration) WithOwnerReferences(values ...*metav1.OwnerReferenceApplyConfiguration) *RuntimeClassApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*RuntimeClassApplyConfiguration) WithResourceVersion ¶
func (b *RuntimeClassApplyConfiguration) WithResourceVersion(value string) *RuntimeClassApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithScheduling ¶
func (b *RuntimeClassApplyConfiguration) WithScheduling(value *SchedulingApplyConfiguration) *RuntimeClassApplyConfiguration
WithScheduling sets the Scheduling field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Scheduling field is set to the value of the last call.
func (*RuntimeClassApplyConfiguration) WithUID ¶
func (b *RuntimeClassApplyConfiguration) WithUID(value types.UID) *RuntimeClassApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type SchedulingApplyConfiguration ¶
type SchedulingApplyConfiguration struct {
// nodeSelector lists labels that must be present on nodes that support this
// RuntimeClass. Pods using this RuntimeClass can only be scheduled to a
// node matched by this selector. The RuntimeClass nodeSelector is merged
// with a pod's existing nodeSelector. Any conflicts will cause the pod to
// be rejected in admission.
NodeSelector map[string]string `json:"nodeSelector,omitempty"`
// tolerations are appended (excluding duplicates) to pods running with this
// RuntimeClass during admission, effectively unioning the set of nodes
// tolerated by the pod and the RuntimeClass.
Tolerations []corev1.TolerationApplyConfiguration `json:"tolerations,omitempty"`
}
SchedulingApplyConfiguration represents a declarative configuration of the Scheduling type for use with apply.
Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass.
func Scheduling ¶
func Scheduling() *SchedulingApplyConfiguration
SchedulingApplyConfiguration constructs a declarative configuration of the Scheduling type for use with apply.
func (*SchedulingApplyConfiguration) WithNodeSelector ¶
func (b *SchedulingApplyConfiguration) WithNodeSelector(entries map[string]string) *SchedulingApplyConfiguration
WithNodeSelector puts the entries into the NodeSelector field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the NodeSelector field, overwriting an existing map entries in NodeSelector field with the same key.
func (*SchedulingApplyConfiguration) WithTolerations ¶
func (b *SchedulingApplyConfiguration) WithTolerations(values ...*corev1.TolerationApplyConfiguration) *SchedulingApplyConfiguration
WithTolerations adds the given value to the Tolerations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Tolerations field.