package v1beta1
import "k8s.io/client-go/applyconfigurations/policy/v1beta1"
Index ¶
- type EvictionApplyConfiguration
- func Eviction(name, namespace string) *EvictionApplyConfiguration
- func ExtractEviction(eviction *policyv1beta1.Eviction, fieldManager string) (*EvictionApplyConfiguration, error)
- func ExtractEvictionFrom(eviction *policyv1beta1.Eviction, fieldManager string, subresource string) (*EvictionApplyConfiguration, error)
- func (b *EvictionApplyConfiguration) GetAPIVersion() *string
- func (b *EvictionApplyConfiguration) GetKind() *string
- func (b *EvictionApplyConfiguration) GetName() *string
- func (b *EvictionApplyConfiguration) GetNamespace() *string
- func (b EvictionApplyConfiguration) IsApplyConfiguration()
- func (b *EvictionApplyConfiguration) WithAPIVersion(value string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithAnnotations(entries map[string]string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithCreationTimestamp(value metav1.Time) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithDeleteOptions(value *v1.DeleteOptionsApplyConfiguration) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithFinalizers(values ...string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithGenerateName(value string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithGeneration(value int64) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithKind(value string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithLabels(entries map[string]string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithName(value string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithNamespace(value string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithResourceVersion(value string) *EvictionApplyConfiguration
- func (b *EvictionApplyConfiguration) WithUID(value types.UID) *EvictionApplyConfiguration
- type PodDisruptionBudgetApplyConfiguration
- func ExtractPodDisruptionBudget(podDisruptionBudget *policyv1beta1.PodDisruptionBudget, fieldManager string) (*PodDisruptionBudgetApplyConfiguration, error)
- func ExtractPodDisruptionBudgetFrom(podDisruptionBudget *policyv1beta1.PodDisruptionBudget, fieldManager string, subresource string) (*PodDisruptionBudgetApplyConfiguration, error)
- func ExtractPodDisruptionBudgetStatus(podDisruptionBudget *policyv1beta1.PodDisruptionBudget, fieldManager string) (*PodDisruptionBudgetApplyConfiguration, error)
- func PodDisruptionBudget(name, namespace string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) GetAPIVersion() *string
- func (b *PodDisruptionBudgetApplyConfiguration) GetKind() *string
- func (b *PodDisruptionBudgetApplyConfiguration) GetName() *string
- func (b *PodDisruptionBudgetApplyConfiguration) GetNamespace() *string
- func (b PodDisruptionBudgetApplyConfiguration) IsApplyConfiguration()
- func (b *PodDisruptionBudgetApplyConfiguration) WithAPIVersion(value string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithAnnotations(entries map[string]string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithCreationTimestamp(value metav1.Time) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithFinalizers(values ...string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithGenerateName(value string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithGeneration(value int64) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithKind(value string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithLabels(entries map[string]string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithName(value string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithNamespace(value string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithResourceVersion(value string) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithSpec(value *PodDisruptionBudgetSpecApplyConfiguration) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithStatus(value *PodDisruptionBudgetStatusApplyConfiguration) *PodDisruptionBudgetApplyConfiguration
- func (b *PodDisruptionBudgetApplyConfiguration) WithUID(value types.UID) *PodDisruptionBudgetApplyConfiguration
- type PodDisruptionBudgetSpecApplyConfiguration
- func PodDisruptionBudgetSpec() *PodDisruptionBudgetSpecApplyConfiguration
- func (b *PodDisruptionBudgetSpecApplyConfiguration) WithMaxUnavailable(value intstr.IntOrString) *PodDisruptionBudgetSpecApplyConfiguration
- func (b *PodDisruptionBudgetSpecApplyConfiguration) WithMinAvailable(value intstr.IntOrString) *PodDisruptionBudgetSpecApplyConfiguration
- func (b *PodDisruptionBudgetSpecApplyConfiguration) WithSelector(value *v1.LabelSelectorApplyConfiguration) *PodDisruptionBudgetSpecApplyConfiguration
- func (b *PodDisruptionBudgetSpecApplyConfiguration) WithUnhealthyPodEvictionPolicy(value policyv1beta1.UnhealthyPodEvictionPolicyType) *PodDisruptionBudgetSpecApplyConfiguration
- type PodDisruptionBudgetStatusApplyConfiguration
- func PodDisruptionBudgetStatus() *PodDisruptionBudgetStatusApplyConfiguration
- func (b *PodDisruptionBudgetStatusApplyConfiguration) WithConditions(values ...*metav1.ConditionApplyConfiguration) *PodDisruptionBudgetStatusApplyConfiguration
- func (b *PodDisruptionBudgetStatusApplyConfiguration) WithCurrentHealthy(value int32) *PodDisruptionBudgetStatusApplyConfiguration
- func (b *PodDisruptionBudgetStatusApplyConfiguration) WithDesiredHealthy(value int32) *PodDisruptionBudgetStatusApplyConfiguration
- func (b *PodDisruptionBudgetStatusApplyConfiguration) WithDisruptedPods(entries map[string]v1.Time) *PodDisruptionBudgetStatusApplyConfiguration
- func (b *PodDisruptionBudgetStatusApplyConfiguration) WithDisruptionsAllowed(value int32) *PodDisruptionBudgetStatusApplyConfiguration
- func (b *PodDisruptionBudgetStatusApplyConfiguration) WithExpectedPods(value int32) *PodDisruptionBudgetStatusApplyConfiguration
- func (b *PodDisruptionBudgetStatusApplyConfiguration) WithObservedGeneration(value int64) *PodDisruptionBudgetStatusApplyConfiguration
Types ¶
type EvictionApplyConfiguration ¶
type EvictionApplyConfiguration struct {
v1.TypeMetaApplyConfiguration `json:",inline"`
// ObjectMeta describes the pod that is being evicted.
*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
// DeleteOptions may be provided
DeleteOptions *v1.DeleteOptionsApplyConfiguration `json:"deleteOptions,omitempty"`
}
EvictionApplyConfiguration represents a declarative configuration of the Eviction type for use with apply.
Eviction evicts a pod from its node subject to certain policies and safety constraints. This is a subresource of Pod. A request to cause such an eviction is created by POSTing to .../pods/<pod name>/evictions.
func Eviction ¶
func Eviction(name, namespace string) *EvictionApplyConfiguration
Eviction constructs a declarative configuration of the Eviction type for use with apply.
func ExtractEviction ¶
func ExtractEviction(eviction *policyv1beta1.Eviction, fieldManager string) (*EvictionApplyConfiguration, error)
ExtractEviction extracts the applied configuration owned by fieldManager from eviction. If no managedFields are found in eviction for fieldManager, a EvictionApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. eviction must be a unmodified Eviction API object that was retrieved from the Kubernetes API. ExtractEviction provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractEvictionFrom ¶
func ExtractEvictionFrom(eviction *policyv1beta1.Eviction, fieldManager string, subresource string) (*EvictionApplyConfiguration, error)
ExtractEvictionFrom extracts the applied configuration owned by fieldManager from eviction for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. eviction must be a unmodified Eviction API object that was retrieved from the Kubernetes API. ExtractEvictionFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func (*EvictionApplyConfiguration) GetAPIVersion ¶
func (b *EvictionApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*EvictionApplyConfiguration) GetKind ¶
func (b *EvictionApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*EvictionApplyConfiguration) GetName ¶
func (b *EvictionApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*EvictionApplyConfiguration) GetNamespace ¶
func (b *EvictionApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (EvictionApplyConfiguration) IsApplyConfiguration ¶
func (b EvictionApplyConfiguration) IsApplyConfiguration()
func (*EvictionApplyConfiguration) WithAPIVersion ¶
func (b *EvictionApplyConfiguration) WithAPIVersion(value string) *EvictionApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithAnnotations ¶
func (b *EvictionApplyConfiguration) WithAnnotations(entries map[string]string) *EvictionApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*EvictionApplyConfiguration) WithCreationTimestamp ¶
func (b *EvictionApplyConfiguration) WithCreationTimestamp(value metav1.Time) *EvictionApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithDeleteOptions ¶
func (b *EvictionApplyConfiguration) WithDeleteOptions(value *v1.DeleteOptionsApplyConfiguration) *EvictionApplyConfiguration
WithDeleteOptions sets the DeleteOptions field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeleteOptions field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *EvictionApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *EvictionApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithDeletionTimestamp ¶
func (b *EvictionApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *EvictionApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithFinalizers ¶
func (b *EvictionApplyConfiguration) WithFinalizers(values ...string) *EvictionApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*EvictionApplyConfiguration) WithGenerateName ¶
func (b *EvictionApplyConfiguration) WithGenerateName(value string) *EvictionApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithGeneration ¶
func (b *EvictionApplyConfiguration) WithGeneration(value int64) *EvictionApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithKind ¶
func (b *EvictionApplyConfiguration) WithKind(value string) *EvictionApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithLabels ¶
func (b *EvictionApplyConfiguration) WithLabels(entries map[string]string) *EvictionApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*EvictionApplyConfiguration) WithName ¶
func (b *EvictionApplyConfiguration) WithName(value string) *EvictionApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithNamespace ¶
func (b *EvictionApplyConfiguration) WithNamespace(value string) *EvictionApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithOwnerReferences ¶
func (b *EvictionApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *EvictionApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*EvictionApplyConfiguration) WithResourceVersion ¶
func (b *EvictionApplyConfiguration) WithResourceVersion(value string) *EvictionApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*EvictionApplyConfiguration) WithUID ¶
func (b *EvictionApplyConfiguration) WithUID(value types.UID) *EvictionApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type PodDisruptionBudgetApplyConfiguration ¶
type PodDisruptionBudgetApplyConfiguration struct {
v1.TypeMetaApplyConfiguration `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
// Specification of the desired behavior of the PodDisruptionBudget.
Spec *PodDisruptionBudgetSpecApplyConfiguration `json:"spec,omitempty"`
// Most recently observed status of the PodDisruptionBudget.
Status *PodDisruptionBudgetStatusApplyConfiguration `json:"status,omitempty"`
}
PodDisruptionBudgetApplyConfiguration represents a declarative configuration of the PodDisruptionBudget type for use with apply.
PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods
func ExtractPodDisruptionBudget ¶
func ExtractPodDisruptionBudget(podDisruptionBudget *policyv1beta1.PodDisruptionBudget, fieldManager string) (*PodDisruptionBudgetApplyConfiguration, error)
ExtractPodDisruptionBudget extracts the applied configuration owned by fieldManager from podDisruptionBudget. If no managedFields are found in podDisruptionBudget for fieldManager, a PodDisruptionBudgetApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. podDisruptionBudget must be a unmodified PodDisruptionBudget API object that was retrieved from the Kubernetes API. ExtractPodDisruptionBudget provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractPodDisruptionBudgetFrom ¶
func ExtractPodDisruptionBudgetFrom(podDisruptionBudget *policyv1beta1.PodDisruptionBudget, fieldManager string, subresource string) (*PodDisruptionBudgetApplyConfiguration, error)
ExtractPodDisruptionBudgetFrom extracts the applied configuration owned by fieldManager from podDisruptionBudget for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. podDisruptionBudget must be a unmodified PodDisruptionBudget API object that was retrieved from the Kubernetes API. ExtractPodDisruptionBudgetFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractPodDisruptionBudgetStatus ¶
func ExtractPodDisruptionBudgetStatus(podDisruptionBudget *policyv1beta1.PodDisruptionBudget, fieldManager string) (*PodDisruptionBudgetApplyConfiguration, error)
ExtractPodDisruptionBudgetStatus extracts the applied configuration owned by fieldManager from podDisruptionBudget for the status subresource.
func PodDisruptionBudget ¶
func PodDisruptionBudget(name, namespace string) *PodDisruptionBudgetApplyConfiguration
PodDisruptionBudget constructs a declarative configuration of the PodDisruptionBudget type for use with apply.
func (*PodDisruptionBudgetApplyConfiguration) GetAPIVersion ¶
func (b *PodDisruptionBudgetApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*PodDisruptionBudgetApplyConfiguration) GetKind ¶
func (b *PodDisruptionBudgetApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*PodDisruptionBudgetApplyConfiguration) GetName ¶
func (b *PodDisruptionBudgetApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*PodDisruptionBudgetApplyConfiguration) GetNamespace ¶
func (b *PodDisruptionBudgetApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (PodDisruptionBudgetApplyConfiguration) IsApplyConfiguration ¶
func (b PodDisruptionBudgetApplyConfiguration) IsApplyConfiguration()
func (*PodDisruptionBudgetApplyConfiguration) WithAPIVersion ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithAPIVersion(value string) *PodDisruptionBudgetApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithAnnotations ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithAnnotations(entries map[string]string) *PodDisruptionBudgetApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*PodDisruptionBudgetApplyConfiguration) WithCreationTimestamp ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithCreationTimestamp(value metav1.Time) *PodDisruptionBudgetApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *PodDisruptionBudgetApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithDeletionTimestamp ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *PodDisruptionBudgetApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithFinalizers ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithFinalizers(values ...string) *PodDisruptionBudgetApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*PodDisruptionBudgetApplyConfiguration) WithGenerateName ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithGenerateName(value string) *PodDisruptionBudgetApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithGeneration ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithGeneration(value int64) *PodDisruptionBudgetApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithKind ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithKind(value string) *PodDisruptionBudgetApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithLabels ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithLabels(entries map[string]string) *PodDisruptionBudgetApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*PodDisruptionBudgetApplyConfiguration) WithName ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithName(value string) *PodDisruptionBudgetApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithNamespace ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithNamespace(value string) *PodDisruptionBudgetApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithOwnerReferences ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *PodDisruptionBudgetApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*PodDisruptionBudgetApplyConfiguration) WithResourceVersion ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithResourceVersion(value string) *PodDisruptionBudgetApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithSpec ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithSpec(value *PodDisruptionBudgetSpecApplyConfiguration) *PodDisruptionBudgetApplyConfiguration
WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithStatus ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithStatus(value *PodDisruptionBudgetStatusApplyConfiguration) *PodDisruptionBudgetApplyConfiguration
WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.
func (*PodDisruptionBudgetApplyConfiguration) WithUID ¶
func (b *PodDisruptionBudgetApplyConfiguration) WithUID(value types.UID) *PodDisruptionBudgetApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type PodDisruptionBudgetSpecApplyConfiguration ¶
type PodDisruptionBudgetSpecApplyConfiguration struct {
// An eviction is allowed if at least "minAvailable" pods selected by
// "selector" will still be available after the eviction, i.e. even in the
// absence of the evicted pod. So for example you can prevent all voluntary
// evictions by specifying "100%".
MinAvailable *intstr.IntOrString `json:"minAvailable,omitempty"`
// Label query over pods whose evictions are managed by the disruption
// budget.
// A null selector selects no pods.
// An empty selector ({}) also selects no pods, which differs from standard behavior of selecting all pods.
// In policy/v1, an empty selector will select all pods in the namespace.
Selector *v1.LabelSelectorApplyConfiguration `json:"selector,omitempty"`
// An eviction is allowed if at most "maxUnavailable" pods selected by
// "selector" are unavailable after the eviction, i.e. even in absence of
// the evicted pod. For example, one can prevent all voluntary evictions
// by specifying 0. This is a mutually exclusive setting with "minAvailable".
*intstr.IntOrString `json:"maxUnavailable,omitempty"`
// UnhealthyPodEvictionPolicy defines the criteria for when unhealthy pods
// should be considered for eviction. Current implementation considers healthy pods,
// as pods that have status.conditions item with type="Ready",status="True".
//
// Valid policies are IfHealthyBudget and AlwaysAllow.
// If no policy is specified, the default behavior will be used,
// which corresponds to the IfHealthyBudget policy.
//
// IfHealthyBudget policy means that running pods (status.phase="Running"),
// but not yet healthy can be evicted only if the guarded application is not
// disrupted (status.currentHealthy is at least equal to status.desiredHealthy).
// Healthy pods will be subject to the PDB for eviction.
//
// AlwaysAllow policy means that all running pods (status.phase="Running"),
// but not yet healthy are considered disrupted and can be evicted regardless
// of whether the criteria in a PDB is met. This means perspective running
// pods of a disrupted application might not get a chance to become healthy.
// Healthy pods will be subject to the PDB for eviction.
//
// Additional policies may be added in the future.
// Clients making eviction decisions should disallow eviction of unhealthy pods
// if they encounter an unrecognized policy in this field.
UnhealthyPodEvictionPolicy *policyv1beta1.UnhealthyPodEvictionPolicyType `json:"unhealthyPodEvictionPolicy,omitempty"`
}
PodDisruptionBudgetSpecApplyConfiguration represents a declarative configuration of the PodDisruptionBudgetSpec type for use with apply.
PodDisruptionBudgetSpec is a description of a PodDisruptionBudget.
func PodDisruptionBudgetSpec ¶
func PodDisruptionBudgetSpec() *PodDisruptionBudgetSpecApplyConfiguration
PodDisruptionBudgetSpecApplyConfiguration constructs a declarative configuration of the PodDisruptionBudgetSpec type for use with apply.
func (*PodDisruptionBudgetSpecApplyConfiguration) WithMaxUnavailable ¶
func (b *PodDisruptionBudgetSpecApplyConfiguration) WithMaxUnavailable(value intstr.IntOrString) *PodDisruptionBudgetSpecApplyConfiguration
WithMaxUnavailable sets the MaxUnavailable field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the MaxUnavailable field is set to the value of the last call.
func (*PodDisruptionBudgetSpecApplyConfiguration) WithMinAvailable ¶
func (b *PodDisruptionBudgetSpecApplyConfiguration) WithMinAvailable(value intstr.IntOrString) *PodDisruptionBudgetSpecApplyConfiguration
WithMinAvailable sets the MinAvailable field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the MinAvailable field is set to the value of the last call.
func (*PodDisruptionBudgetSpecApplyConfiguration) WithSelector ¶
func (b *PodDisruptionBudgetSpecApplyConfiguration) WithSelector(value *v1.LabelSelectorApplyConfiguration) *PodDisruptionBudgetSpecApplyConfiguration
WithSelector sets the Selector field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Selector field is set to the value of the last call.
func (*PodDisruptionBudgetSpecApplyConfiguration) WithUnhealthyPodEvictionPolicy ¶
func (b *PodDisruptionBudgetSpecApplyConfiguration) WithUnhealthyPodEvictionPolicy(value policyv1beta1.UnhealthyPodEvictionPolicyType) *PodDisruptionBudgetSpecApplyConfiguration
WithUnhealthyPodEvictionPolicy sets the UnhealthyPodEvictionPolicy field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UnhealthyPodEvictionPolicy field is set to the value of the last call.
type PodDisruptionBudgetStatusApplyConfiguration ¶
type PodDisruptionBudgetStatusApplyConfiguration struct {
// Most recent generation observed when updating this PDB status. DisruptionsAllowed and other
// status information is valid only if observedGeneration equals to PDB's object generation.
ObservedGeneration *int64 `json:"observedGeneration,omitempty"`
// DisruptedPods contains information about pods whose eviction was
// processed by the API server eviction subresource handler but has not
// yet been observed by the PodDisruptionBudget controller.
// A pod will be in this map from the time when the API server processed the
// eviction request to the time when the pod is seen by PDB controller
// as having been marked for deletion (or after a timeout). The key in the map is the name of the pod
// and the value is the time when the API server processed the eviction request. If
// the deletion didn't occur and a pod is still there it will be removed from
// the list automatically by PodDisruptionBudget controller after some time.
// If everything goes smooth this map should be empty for the most of the time.
// Large number of entries in the map may indicate problems with pod deletions.
DisruptedPods map[string]v1.Time `json:"disruptedPods,omitempty"`
// Number of pod disruptions that are currently allowed.
DisruptionsAllowed *int32 `json:"disruptionsAllowed,omitempty"`
// current number of healthy pods
CurrentHealthy *int32 `json:"currentHealthy,omitempty"`
// minimum desired number of healthy pods
DesiredHealthy *int32 `json:"desiredHealthy,omitempty"`
// total number of pods counted by this disruption budget
ExpectedPods *int32 `json:"expectedPods,omitempty"`
// Conditions contain conditions for PDB. The disruption controller sets the
// DisruptionAllowed condition. The following are known values for the reason field
// (additional reasons could be added in the future):
// - SyncFailed: The controller encountered an error and wasn't able to compute
// the number of allowed disruptions. Therefore no disruptions are
// allowed and the status of the condition will be False.
// - InsufficientPods: The number of pods are either at or below the number
// required by the PodDisruptionBudget. No disruptions are
// allowed and the status of the condition will be False.
// - SufficientPods: There are more pods than required by the PodDisruptionBudget.
// The condition will be True, and the number of allowed
// disruptions are provided by the disruptionsAllowed property.
Conditions []metav1.ConditionApplyConfiguration `json:"conditions,omitempty"`
}
PodDisruptionBudgetStatusApplyConfiguration represents a declarative configuration of the PodDisruptionBudgetStatus type for use with apply.
PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system.
func PodDisruptionBudgetStatus ¶
func PodDisruptionBudgetStatus() *PodDisruptionBudgetStatusApplyConfiguration
PodDisruptionBudgetStatusApplyConfiguration constructs a declarative configuration of the PodDisruptionBudgetStatus type for use with apply.
func (*PodDisruptionBudgetStatusApplyConfiguration) WithConditions ¶
func (b *PodDisruptionBudgetStatusApplyConfiguration) WithConditions(values ...*metav1.ConditionApplyConfiguration) *PodDisruptionBudgetStatusApplyConfiguration
WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.
func (*PodDisruptionBudgetStatusApplyConfiguration) WithCurrentHealthy ¶
func (b *PodDisruptionBudgetStatusApplyConfiguration) WithCurrentHealthy(value int32) *PodDisruptionBudgetStatusApplyConfiguration
WithCurrentHealthy sets the CurrentHealthy field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CurrentHealthy field is set to the value of the last call.
func (*PodDisruptionBudgetStatusApplyConfiguration) WithDesiredHealthy ¶
func (b *PodDisruptionBudgetStatusApplyConfiguration) WithDesiredHealthy(value int32) *PodDisruptionBudgetStatusApplyConfiguration
WithDesiredHealthy sets the DesiredHealthy field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DesiredHealthy field is set to the value of the last call.
func (*PodDisruptionBudgetStatusApplyConfiguration) WithDisruptedPods ¶
func (b *PodDisruptionBudgetStatusApplyConfiguration) WithDisruptedPods(entries map[string]v1.Time) *PodDisruptionBudgetStatusApplyConfiguration
WithDisruptedPods puts the entries into the DisruptedPods field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the DisruptedPods field, overwriting an existing map entries in DisruptedPods field with the same key.
func (*PodDisruptionBudgetStatusApplyConfiguration) WithDisruptionsAllowed ¶
func (b *PodDisruptionBudgetStatusApplyConfiguration) WithDisruptionsAllowed(value int32) *PodDisruptionBudgetStatusApplyConfiguration
WithDisruptionsAllowed sets the DisruptionsAllowed field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DisruptionsAllowed field is set to the value of the last call.
func (*PodDisruptionBudgetStatusApplyConfiguration) WithExpectedPods ¶
func (b *PodDisruptionBudgetStatusApplyConfiguration) WithExpectedPods(value int32) *PodDisruptionBudgetStatusApplyConfiguration
WithExpectedPods sets the ExpectedPods field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ExpectedPods field is set to the value of the last call.
func (*PodDisruptionBudgetStatusApplyConfiguration) WithObservedGeneration ¶
func (b *PodDisruptionBudgetStatusApplyConfiguration) WithObservedGeneration(value int64) *PodDisruptionBudgetStatusApplyConfiguration
WithObservedGeneration sets the ObservedGeneration field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ObservedGeneration field is set to the value of the last call.
Source Files ¶
eviction.go poddisruptionbudget.go poddisruptionbudgetspec.go poddisruptionbudgetstatus.go
- Version
- v0.35.0
- Published
- Dec 17, 2025
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 56 minutes ago –
Tools for package owners.