package v1beta1

import "k8s.io/client-go/applyconfigurations/rbac/v1beta1"

Index

Types

type AggregationRuleApplyConfiguration

type AggregationRuleApplyConfiguration struct {
	// ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules.
	// If any of the selectors match, then the ClusterRole's permissions will be added
	ClusterRoleSelectors []v1.LabelSelectorApplyConfiguration `json:"clusterRoleSelectors,omitempty"`
}

AggregationRuleApplyConfiguration represents a declarative configuration of the AggregationRule type for use with apply.

AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole

func AggregationRule

func AggregationRule() *AggregationRuleApplyConfiguration

AggregationRuleApplyConfiguration constructs a declarative configuration of the AggregationRule type for use with apply.

func (*AggregationRuleApplyConfiguration) WithClusterRoleSelectors

WithClusterRoleSelectors adds the given value to the ClusterRoleSelectors field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the ClusterRoleSelectors field.

type ClusterRoleApplyConfiguration

type ClusterRoleApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object's metadata.
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Rules holds all the PolicyRules for this ClusterRole
	Rules []PolicyRuleApplyConfiguration `json:"rules,omitempty"`
	// AggregationRule is an optional field that describes how to build the Rules for this ClusterRole.
	// If AggregationRule is set, then the Rules are controller managed and direct changes to Rules will be
	// stomped by the controller.
	AggregationRule *AggregationRuleApplyConfiguration `json:"aggregationRule,omitempty"`
}

ClusterRoleApplyConfiguration represents a declarative configuration of the ClusterRole type for use with apply.

ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRole, and will no longer be served in v1.22.

func ClusterRole

func ClusterRole(name string) *ClusterRoleApplyConfiguration

ClusterRole constructs a declarative configuration of the ClusterRole type for use with apply.

func ExtractClusterRole

func ExtractClusterRole(clusterRole *rbacv1beta1.ClusterRole, fieldManager string) (*ClusterRoleApplyConfiguration, error)

ExtractClusterRole extracts the applied configuration owned by fieldManager from clusterRole. If no managedFields are found in clusterRole for fieldManager, a ClusterRoleApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. clusterRole must be a unmodified ClusterRole API object that was retrieved from the Kubernetes API. ExtractClusterRole provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractClusterRoleFrom

func ExtractClusterRoleFrom(clusterRole *rbacv1beta1.ClusterRole, fieldManager string, subresource string) (*ClusterRoleApplyConfiguration, error)

ExtractClusterRoleFrom extracts the applied configuration owned by fieldManager from clusterRole for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. clusterRole must be a unmodified ClusterRole API object that was retrieved from the Kubernetes API. ExtractClusterRoleFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func (*ClusterRoleApplyConfiguration) GetAPIVersion

func (b *ClusterRoleApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*ClusterRoleApplyConfiguration) GetKind

func (b *ClusterRoleApplyConfiguration) GetKind() *string

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*ClusterRoleApplyConfiguration) GetName

func (b *ClusterRoleApplyConfiguration) GetName() *string

GetName retrieves the value of the Name field in the declarative configuration.

func (*ClusterRoleApplyConfiguration) GetNamespace

func (b *ClusterRoleApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (ClusterRoleApplyConfiguration) IsApplyConfiguration

func (b ClusterRoleApplyConfiguration) IsApplyConfiguration()

func (*ClusterRoleApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithAggregationRule

WithAggregationRule sets the AggregationRule field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the AggregationRule field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*ClusterRoleApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *ClusterRoleApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ClusterRoleApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*ClusterRoleApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*ClusterRoleApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*ClusterRoleApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*ClusterRoleApplyConfiguration) WithRules

WithRules adds the given value to the Rules field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Rules field.

func (*ClusterRoleApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type ClusterRoleBindingApplyConfiguration

type ClusterRoleBindingApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object's metadata.
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Subjects holds references to the objects the role applies to.
	Subjects []SubjectApplyConfiguration `json:"subjects,omitempty"`
	// RoleRef can only reference a ClusterRole in the global namespace.
	// If the RoleRef cannot be resolved, the Authorizer must return an error.
	RoleRef *RoleRefApplyConfiguration `json:"roleRef,omitempty"`
}

ClusterRoleBindingApplyConfiguration represents a declarative configuration of the ClusterRoleBinding type for use with apply.

ClusterRoleBinding references a ClusterRole, but not contain it. It can reference a ClusterRole in the global namespace, and adds who information via Subject. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding, and will no longer be served in v1.22.

func ClusterRoleBinding

func ClusterRoleBinding(name string) *ClusterRoleBindingApplyConfiguration

ClusterRoleBinding constructs a declarative configuration of the ClusterRoleBinding type for use with apply.

func ExtractClusterRoleBinding

func ExtractClusterRoleBinding(clusterRoleBinding *rbacv1beta1.ClusterRoleBinding, fieldManager string) (*ClusterRoleBindingApplyConfiguration, error)

ExtractClusterRoleBinding extracts the applied configuration owned by fieldManager from clusterRoleBinding. If no managedFields are found in clusterRoleBinding for fieldManager, a ClusterRoleBindingApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. clusterRoleBinding must be a unmodified ClusterRoleBinding API object that was retrieved from the Kubernetes API. ExtractClusterRoleBinding provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractClusterRoleBindingFrom

func ExtractClusterRoleBindingFrom(clusterRoleBinding *rbacv1beta1.ClusterRoleBinding, fieldManager string, subresource string) (*ClusterRoleBindingApplyConfiguration, error)

ExtractClusterRoleBindingFrom extracts the applied configuration owned by fieldManager from clusterRoleBinding for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. clusterRoleBinding must be a unmodified ClusterRoleBinding API object that was retrieved from the Kubernetes API. ExtractClusterRoleBindingFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func (*ClusterRoleBindingApplyConfiguration) GetAPIVersion

func (b *ClusterRoleBindingApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*ClusterRoleBindingApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*ClusterRoleBindingApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*ClusterRoleBindingApplyConfiguration) GetNamespace

func (b *ClusterRoleBindingApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (ClusterRoleBindingApplyConfiguration) IsApplyConfiguration

func (b ClusterRoleBindingApplyConfiguration) IsApplyConfiguration()

func (*ClusterRoleBindingApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*ClusterRoleBindingApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *ClusterRoleBindingApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ClusterRoleBindingApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*ClusterRoleBindingApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*ClusterRoleBindingApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*ClusterRoleBindingApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithRoleRef

WithRoleRef sets the RoleRef field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the RoleRef field is set to the value of the last call.

func (*ClusterRoleBindingApplyConfiguration) WithSubjects

WithSubjects adds the given value to the Subjects field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Subjects field.

func (*ClusterRoleBindingApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type PolicyRuleApplyConfiguration

type PolicyRuleApplyConfiguration struct {
	// Verbs is a list of Verbs that apply to ALL the ResourceKinds contained in this rule. '*' represents all verbs.
	Verbs []string `json:"verbs,omitempty"`
	// APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of
	// the enumerated resources in any API group will be allowed. "" represents the core API group and "*" represents all API groups.
	APIGroups []string `json:"apiGroups,omitempty"`
	// Resources is a list of resources this rule applies to.  '*' represents all resources in the specified apiGroups.
	// '*/foo' represents the subresource 'foo' for all resources in the specified apiGroups.
	Resources []string `json:"resources,omitempty"`
	// ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.
	ResourceNames []string `json:"resourceNames,omitempty"`
	// NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path
	// Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding.
	// Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both.
	NonResourceURLs []string `json:"nonResourceURLs,omitempty"`
}

PolicyRuleApplyConfiguration represents a declarative configuration of the PolicyRule type for use with apply.

Authorization is calculated against 1. evaluation of ClusterRoleBindings - short circuit on match 2. evaluation of RoleBindings in the namespace requested - short circuit on match 3. deny by default PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to.

func PolicyRule

func PolicyRule() *PolicyRuleApplyConfiguration

PolicyRuleApplyConfiguration constructs a declarative configuration of the PolicyRule type for use with apply.

func (*PolicyRuleApplyConfiguration) WithAPIGroups

WithAPIGroups adds the given value to the APIGroups field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the APIGroups field.

func (*PolicyRuleApplyConfiguration) WithNonResourceURLs

func (b *PolicyRuleApplyConfiguration) WithNonResourceURLs(values ...string) *PolicyRuleApplyConfiguration

WithNonResourceURLs adds the given value to the NonResourceURLs field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the NonResourceURLs field.

func (*PolicyRuleApplyConfiguration) WithResourceNames

func (b *PolicyRuleApplyConfiguration) WithResourceNames(values ...string) *PolicyRuleApplyConfiguration

WithResourceNames adds the given value to the ResourceNames field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the ResourceNames field.

func (*PolicyRuleApplyConfiguration) WithResources

WithResources adds the given value to the Resources field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Resources field.

func (*PolicyRuleApplyConfiguration) WithVerbs

WithVerbs adds the given value to the Verbs field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Verbs field.

type RoleApplyConfiguration

type RoleApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object's metadata.
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Rules holds all the PolicyRules for this Role
	Rules []PolicyRuleApplyConfiguration `json:"rules,omitempty"`
}

RoleApplyConfiguration represents a declarative configuration of the Role type for use with apply.

Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and will no longer be served in v1.22.

func ExtractRole

func ExtractRole(role *rbacv1beta1.Role, fieldManager string) (*RoleApplyConfiguration, error)

ExtractRole extracts the applied configuration owned by fieldManager from role. If no managedFields are found in role for fieldManager, a RoleApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. role must be a unmodified Role API object that was retrieved from the Kubernetes API. ExtractRole provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractRoleFrom

func ExtractRoleFrom(role *rbacv1beta1.Role, fieldManager string, subresource string) (*RoleApplyConfiguration, error)

ExtractRoleFrom extracts the applied configuration owned by fieldManager from role for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. role must be a unmodified Role API object that was retrieved from the Kubernetes API. ExtractRoleFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func Role

func Role(name, namespace string) *RoleApplyConfiguration

Role constructs a declarative configuration of the Role type for use with apply.

func (*RoleApplyConfiguration) GetAPIVersion

func (b *RoleApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*RoleApplyConfiguration) GetKind

func (b *RoleApplyConfiguration) GetKind() *string

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*RoleApplyConfiguration) GetName

func (b *RoleApplyConfiguration) GetName() *string

GetName retrieves the value of the Name field in the declarative configuration.

func (*RoleApplyConfiguration) GetNamespace

func (b *RoleApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (RoleApplyConfiguration) IsApplyConfiguration

func (b RoleApplyConfiguration) IsApplyConfiguration()

func (*RoleApplyConfiguration) WithAPIVersion

func (b *RoleApplyConfiguration) WithAPIVersion(value string) *RoleApplyConfiguration

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*RoleApplyConfiguration) WithAnnotations

func (b *RoleApplyConfiguration) WithAnnotations(entries map[string]string) *RoleApplyConfiguration

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*RoleApplyConfiguration) WithCreationTimestamp

func (b *RoleApplyConfiguration) WithCreationTimestamp(value metav1.Time) *RoleApplyConfiguration

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*RoleApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *RoleApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *RoleApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*RoleApplyConfiguration) WithDeletionTimestamp

func (b *RoleApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *RoleApplyConfiguration

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*RoleApplyConfiguration) WithFinalizers

func (b *RoleApplyConfiguration) WithFinalizers(values ...string) *RoleApplyConfiguration

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*RoleApplyConfiguration) WithGenerateName

func (b *RoleApplyConfiguration) WithGenerateName(value string) *RoleApplyConfiguration

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*RoleApplyConfiguration) WithGeneration

func (b *RoleApplyConfiguration) WithGeneration(value int64) *RoleApplyConfiguration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*RoleApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*RoleApplyConfiguration) WithLabels

func (b *RoleApplyConfiguration) WithLabels(entries map[string]string) *RoleApplyConfiguration

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*RoleApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*RoleApplyConfiguration) WithNamespace

func (b *RoleApplyConfiguration) WithNamespace(value string) *RoleApplyConfiguration

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*RoleApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*RoleApplyConfiguration) WithResourceVersion

func (b *RoleApplyConfiguration) WithResourceVersion(value string) *RoleApplyConfiguration

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*RoleApplyConfiguration) WithRules

WithRules adds the given value to the Rules field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Rules field.

func (*RoleApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type RoleBindingApplyConfiguration

type RoleBindingApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object's metadata.
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Subjects holds references to the objects the role applies to.
	Subjects []SubjectApplyConfiguration `json:"subjects,omitempty"`
	// RoleRef can reference a Role in the current namespace or a ClusterRole in the global namespace.
	// If the RoleRef cannot be resolved, the Authorizer must return an error.
	RoleRef *RoleRefApplyConfiguration `json:"roleRef,omitempty"`
}

RoleBindingApplyConfiguration represents a declarative configuration of the RoleBinding type for use with apply.

RoleBinding references a role, but does not contain it. It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in. RoleBindings in a given namespace only have effect in that namespace. Deprecated in v1.17 in favor of rbac.authorization.k8s.io/v1 RoleBinding, and will no longer be served in v1.22.

func ExtractRoleBinding

func ExtractRoleBinding(roleBinding *rbacv1beta1.RoleBinding, fieldManager string) (*RoleBindingApplyConfiguration, error)

ExtractRoleBinding extracts the applied configuration owned by fieldManager from roleBinding. If no managedFields are found in roleBinding for fieldManager, a RoleBindingApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. roleBinding must be a unmodified RoleBinding API object that was retrieved from the Kubernetes API. ExtractRoleBinding provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractRoleBindingFrom

func ExtractRoleBindingFrom(roleBinding *rbacv1beta1.RoleBinding, fieldManager string, subresource string) (*RoleBindingApplyConfiguration, error)

ExtractRoleBindingFrom extracts the applied configuration owned by fieldManager from roleBinding for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. roleBinding must be a unmodified RoleBinding API object that was retrieved from the Kubernetes API. ExtractRoleBindingFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func RoleBinding

func RoleBinding(name, namespace string) *RoleBindingApplyConfiguration

RoleBinding constructs a declarative configuration of the RoleBinding type for use with apply.

func (*RoleBindingApplyConfiguration) GetAPIVersion

func (b *RoleBindingApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*RoleBindingApplyConfiguration) GetKind

func (b *RoleBindingApplyConfiguration) GetKind() *string

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*RoleBindingApplyConfiguration) GetName

func (b *RoleBindingApplyConfiguration) GetName() *string

GetName retrieves the value of the Name field in the declarative configuration.

func (*RoleBindingApplyConfiguration) GetNamespace

func (b *RoleBindingApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (RoleBindingApplyConfiguration) IsApplyConfiguration

func (b RoleBindingApplyConfiguration) IsApplyConfiguration()

func (*RoleBindingApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*RoleBindingApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *RoleBindingApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *RoleBindingApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*RoleBindingApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*RoleBindingApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*RoleBindingApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithRoleRef

WithRoleRef sets the RoleRef field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the RoleRef field is set to the value of the last call.

func (*RoleBindingApplyConfiguration) WithSubjects

WithSubjects adds the given value to the Subjects field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Subjects field.

func (*RoleBindingApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type RoleRefApplyConfiguration

type RoleRefApplyConfiguration struct {
	// APIGroup is the group for the resource being referenced
	APIGroup *string `json:"apiGroup,omitempty"`
	// Kind is the type of resource being referenced
	Kind *string `json:"kind,omitempty"`
	// Name is the name of resource being referenced
	Name *string `json:"name,omitempty"`
}

RoleRefApplyConfiguration represents a declarative configuration of the RoleRef type for use with apply.

RoleRef contains information that points to the role being used

func RoleRef

func RoleRef() *RoleRefApplyConfiguration

RoleRefApplyConfiguration constructs a declarative configuration of the RoleRef type for use with apply.

func (*RoleRefApplyConfiguration) WithAPIGroup

WithAPIGroup sets the APIGroup field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIGroup field is set to the value of the last call.

func (*RoleRefApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*RoleRefApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

type SubjectApplyConfiguration

type SubjectApplyConfiguration struct {
	// Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount".
	// If the Authorizer does not recognized the kind value, the Authorizer should report an error.
	Kind *string `json:"kind,omitempty"`
	// APIGroup holds the API group of the referenced subject.
	// Defaults to "" for ServiceAccount subjects.
	// Defaults to "rbac.authorization.k8s.io" for User and Group subjects.
	APIGroup *string `json:"apiGroup,omitempty"`
	// Name of the object being referenced.
	Name *string `json:"name,omitempty"`
	// Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty
	// the Authorizer should report an error.
	Namespace *string `json:"namespace,omitempty"`
}

SubjectApplyConfiguration represents a declarative configuration of the Subject type for use with apply.

Subject contains a reference to the object or user identities a role binding applies to. This can either hold a direct API object reference, or a value for non-objects such as user and group names.

func Subject

func Subject() *SubjectApplyConfiguration

SubjectApplyConfiguration constructs a declarative configuration of the Subject type for use with apply.

func (*SubjectApplyConfiguration) WithAPIGroup

WithAPIGroup sets the APIGroup field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIGroup field is set to the value of the last call.

func (*SubjectApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*SubjectApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*SubjectApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

Source Files

aggregationrule.go clusterrole.go clusterrolebinding.go policyrule.go role.go rolebinding.go roleref.go subject.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
6 packages
Last checked
2 minutes ago

Tools for package owners.