package v1alpha1

import "k8s.io/client-go/applyconfigurations/storage/v1alpha1"

Index

Types

type CSIStorageCapacityApplyConfiguration

type CSIStorageCapacityApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object's metadata. The name has no particular meaning. It must be
	// be a DNS subdomain (dots allowed, 253 characters). To ensure that
	// there are no conflicts with other CSI drivers on the cluster, the recommendation
	// is to use csisc-<uuid>, a generated name, or a reverse-domain name which ends
	// with the unique CSI driver name.
	//
	// Objects are namespaced.
	//
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// nodeTopology defines which nodes have access to the storage
	// for which capacity was reported. If not set, the storage is
	// not accessible from any node in the cluster. If empty, the
	// storage is accessible from all nodes. This field is
	// immutable.
	NodeTopology *v1.LabelSelectorApplyConfiguration `json:"nodeTopology,omitempty"`
	// storageClassName represents the name of the StorageClass that the reported capacity applies to.
	// It must meet the same requirements as the name of a StorageClass
	// object (non-empty, DNS subdomain). If that object no longer exists,
	// the CSIStorageCapacity object is obsolete and should be removed by its
	// creator.
	// This field is immutable.
	StorageClassName *string `json:"storageClassName,omitempty"`
	// capacity is the value reported by the CSI driver in its GetCapacityResponse
	// for a GetCapacityRequest with topology and parameters that match the
	// previous fields.
	//
	// The semantic is currently (CSI spec 1.2) defined as:
	// The available capacity, in bytes, of the storage that can be used
	// to provision volumes. If not set, that information is currently
	// unavailable.
	Capacity *resource.Quantity `json:"capacity,omitempty"`
	// maximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse
	// for a GetCapacityRequest with topology and parameters that match the
	// previous fields.
	//
	// This is defined since CSI spec 1.4.0 as the largest size
	// that may be used in a
	// CreateVolumeRequest.capacity_range.required_bytes field to
	// create a volume with the same parameters as those in
	// GetCapacityRequest. The corresponding value in the Kubernetes
	// API is ResourceRequirements.Requests in a volume claim.
	MaximumVolumeSize *resource.Quantity `json:"maximumVolumeSize,omitempty"`
}

CSIStorageCapacityApplyConfiguration represents a declarative configuration of the CSIStorageCapacity type for use with apply.

CSIStorageCapacity stores the result of one CSI GetCapacity call. For a given StorageClass, this describes the available capacity in a particular topology segment. This can be used when considering where to instantiate new PersistentVolumes.

For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"

The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero

The producer of these objects can decide which approach is more suitable.

They are consumed by the kube-scheduler when a CSI driver opts into capacity-aware scheduling with CSIDriverSpec.StorageCapacity. The scheduler compares the MaximumVolumeSize against the requested size of pending volumes to filter out unsuitable nodes. If MaximumVolumeSize is unset, it falls back to a comparison against the less precise Capacity. If that is also unset, the scheduler assumes that capacity is insufficient and tries some other node.

func CSIStorageCapacity

func CSIStorageCapacity(name, namespace string) *CSIStorageCapacityApplyConfiguration

CSIStorageCapacity constructs a declarative configuration of the CSIStorageCapacity type for use with apply.

func ExtractCSIStorageCapacity

func ExtractCSIStorageCapacity(cSIStorageCapacity *storagev1alpha1.CSIStorageCapacity, fieldManager string) (*CSIStorageCapacityApplyConfiguration, error)

ExtractCSIStorageCapacity extracts the applied configuration owned by fieldManager from cSIStorageCapacity. If no managedFields are found in cSIStorageCapacity for fieldManager, a CSIStorageCapacityApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. cSIStorageCapacity must be a unmodified CSIStorageCapacity API object that was retrieved from the Kubernetes API. ExtractCSIStorageCapacity provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractCSIStorageCapacityFrom

func ExtractCSIStorageCapacityFrom(cSIStorageCapacity *storagev1alpha1.CSIStorageCapacity, fieldManager string, subresource string) (*CSIStorageCapacityApplyConfiguration, error)

ExtractCSIStorageCapacityFrom extracts the applied configuration owned by fieldManager from cSIStorageCapacity for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. cSIStorageCapacity must be a unmodified CSIStorageCapacity API object that was retrieved from the Kubernetes API. ExtractCSIStorageCapacityFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func (*CSIStorageCapacityApplyConfiguration) GetAPIVersion

func (b *CSIStorageCapacityApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*CSIStorageCapacityApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*CSIStorageCapacityApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*CSIStorageCapacityApplyConfiguration) GetNamespace

func (b *CSIStorageCapacityApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (CSIStorageCapacityApplyConfiguration) IsApplyConfiguration

func (b CSIStorageCapacityApplyConfiguration) IsApplyConfiguration()

func (*CSIStorageCapacityApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*CSIStorageCapacityApplyConfiguration) WithCapacity

WithCapacity sets the Capacity field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Capacity field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *CSIStorageCapacityApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *CSIStorageCapacityApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*CSIStorageCapacityApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*CSIStorageCapacityApplyConfiguration) WithMaximumVolumeSize

WithMaximumVolumeSize sets the MaximumVolumeSize field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the MaximumVolumeSize field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithNodeTopology

WithNodeTopology sets the NodeTopology field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the NodeTopology field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*CSIStorageCapacityApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithStorageClassName

WithStorageClassName sets the StorageClassName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the StorageClassName field is set to the value of the last call.

func (*CSIStorageCapacityApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type VolumeAttachmentApplyConfiguration

type VolumeAttachmentApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object metadata.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// spec represents specification of the desired attach/detach volume behavior.
	// Populated by the Kubernetes system.
	Spec *VolumeAttachmentSpecApplyConfiguration `json:"spec,omitempty"`
	// status represents status of the VolumeAttachment request.
	// Populated by the entity completing the attach or detach
	// operation, i.e. the external-attacher.
	Status *VolumeAttachmentStatusApplyConfiguration `json:"status,omitempty"`
}

VolumeAttachmentApplyConfiguration represents a declarative configuration of the VolumeAttachment type for use with apply.

VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.

VolumeAttachment objects are non-namespaced.

func ExtractVolumeAttachment

func ExtractVolumeAttachment(volumeAttachment *storagev1alpha1.VolumeAttachment, fieldManager string) (*VolumeAttachmentApplyConfiguration, error)

ExtractVolumeAttachment extracts the applied configuration owned by fieldManager from volumeAttachment. If no managedFields are found in volumeAttachment for fieldManager, a VolumeAttachmentApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. volumeAttachment must be a unmodified VolumeAttachment API object that was retrieved from the Kubernetes API. ExtractVolumeAttachment provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractVolumeAttachmentFrom

func ExtractVolumeAttachmentFrom(volumeAttachment *storagev1alpha1.VolumeAttachment, fieldManager string, subresource string) (*VolumeAttachmentApplyConfiguration, error)

ExtractVolumeAttachmentFrom extracts the applied configuration owned by fieldManager from volumeAttachment for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. volumeAttachment must be a unmodified VolumeAttachment API object that was retrieved from the Kubernetes API. ExtractVolumeAttachmentFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractVolumeAttachmentStatus

func ExtractVolumeAttachmentStatus(volumeAttachment *storagev1alpha1.VolumeAttachment, fieldManager string) (*VolumeAttachmentApplyConfiguration, error)

ExtractVolumeAttachmentStatus extracts the applied configuration owned by fieldManager from volumeAttachment for the status subresource.

func VolumeAttachment

func VolumeAttachment(name string) *VolumeAttachmentApplyConfiguration

VolumeAttachment constructs a declarative configuration of the VolumeAttachment type for use with apply.

func (*VolumeAttachmentApplyConfiguration) GetAPIVersion

func (b *VolumeAttachmentApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*VolumeAttachmentApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*VolumeAttachmentApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*VolumeAttachmentApplyConfiguration) GetNamespace

func (b *VolumeAttachmentApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (VolumeAttachmentApplyConfiguration) IsApplyConfiguration

func (b VolumeAttachmentApplyConfiguration) IsApplyConfiguration()

func (*VolumeAttachmentApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*VolumeAttachmentApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *VolumeAttachmentApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *VolumeAttachmentApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*VolumeAttachmentApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*VolumeAttachmentApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*VolumeAttachmentApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*VolumeAttachmentApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type VolumeAttachmentSourceApplyConfiguration

type VolumeAttachmentSourceApplyConfiguration struct {
	// persistentVolumeName represents the name of the persistent volume to attach.
	PersistentVolumeName *string `json:"persistentVolumeName,omitempty"`
	// inlineVolumeSpec contains all the information necessary to attach
	// a persistent volume defined by a pod's inline VolumeSource. This field
	// is populated only for the CSIMigration feature. It contains
	// translated fields from a pod's inline VolumeSource to a
	// PersistentVolumeSpec. This field is alpha-level and is only
	// honored by servers that enabled the CSIMigration feature.
	InlineVolumeSpec *v1.PersistentVolumeSpecApplyConfiguration `json:"inlineVolumeSpec,omitempty"`
}

VolumeAttachmentSourceApplyConfiguration represents a declarative configuration of the VolumeAttachmentSource type for use with apply.

VolumeAttachmentSource represents a volume that should be attached. Right now only PersistentVolumes can be attached via external attacher, in the future we may allow also inline volumes in pods. Exactly one member can be set.

func VolumeAttachmentSource

func VolumeAttachmentSource() *VolumeAttachmentSourceApplyConfiguration

VolumeAttachmentSourceApplyConfiguration constructs a declarative configuration of the VolumeAttachmentSource type for use with apply.

func (*VolumeAttachmentSourceApplyConfiguration) WithInlineVolumeSpec

WithInlineVolumeSpec sets the InlineVolumeSpec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the InlineVolumeSpec field is set to the value of the last call.

func (*VolumeAttachmentSourceApplyConfiguration) WithPersistentVolumeName

WithPersistentVolumeName sets the PersistentVolumeName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the PersistentVolumeName field is set to the value of the last call.

type VolumeAttachmentSpecApplyConfiguration

type VolumeAttachmentSpecApplyConfiguration struct {
	// attacher indicates the name of the volume driver that MUST handle this
	// request. This is the name returned by GetPluginName().
	Attacher *string `json:"attacher,omitempty"`
	// source represents the volume that should be attached.
	Source *VolumeAttachmentSourceApplyConfiguration `json:"source,omitempty"`
	// nodeName represents the node that the volume should be attached to.
	NodeName *string `json:"nodeName,omitempty"`
}

VolumeAttachmentSpecApplyConfiguration represents a declarative configuration of the VolumeAttachmentSpec type for use with apply.

VolumeAttachmentSpec is the specification of a VolumeAttachment request.

func VolumeAttachmentSpec

func VolumeAttachmentSpec() *VolumeAttachmentSpecApplyConfiguration

VolumeAttachmentSpecApplyConfiguration constructs a declarative configuration of the VolumeAttachmentSpec type for use with apply.

func (*VolumeAttachmentSpecApplyConfiguration) WithAttacher

WithAttacher sets the Attacher field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Attacher field is set to the value of the last call.

func (*VolumeAttachmentSpecApplyConfiguration) WithNodeName

WithNodeName sets the NodeName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the NodeName field is set to the value of the last call.

func (*VolumeAttachmentSpecApplyConfiguration) WithSource

WithSource sets the Source field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Source field is set to the value of the last call.

type VolumeAttachmentStatusApplyConfiguration

type VolumeAttachmentStatusApplyConfiguration struct {
	// attached indicates the volume is successfully attached.
	// This field must only be set by the entity completing the attach
	// operation, i.e. the external-attacher.
	Attached *bool `json:"attached,omitempty"`
	// attachmentMetadata is populated with any
	// information returned by the attach operation, upon successful attach, that must be passed
	// into subsequent WaitForAttach or Mount calls.
	// This field must only be set by the entity completing the attach
	// operation, i.e. the external-attacher.
	AttachmentMetadata map[string]string `json:"attachmentMetadata,omitempty"`
	// attachError represents the last error encountered during attach operation, if any.
	// This field must only be set by the entity completing the attach
	// operation, i.e. the external-attacher.
	AttachError *VolumeErrorApplyConfiguration `json:"attachError,omitempty"`
	// detachError represents the last error encountered during detach operation, if any.
	// This field must only be set by the entity completing the detach
	// operation, i.e. the external-attacher.
	DetachError *VolumeErrorApplyConfiguration `json:"detachError,omitempty"`
}

VolumeAttachmentStatusApplyConfiguration represents a declarative configuration of the VolumeAttachmentStatus type for use with apply.

VolumeAttachmentStatus is the status of a VolumeAttachment request.

func VolumeAttachmentStatus

func VolumeAttachmentStatus() *VolumeAttachmentStatusApplyConfiguration

VolumeAttachmentStatusApplyConfiguration constructs a declarative configuration of the VolumeAttachmentStatus type for use with apply.

func (*VolumeAttachmentStatusApplyConfiguration) WithAttachError

WithAttachError sets the AttachError field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the AttachError field is set to the value of the last call.

func (*VolumeAttachmentStatusApplyConfiguration) WithAttached

WithAttached sets the Attached field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Attached field is set to the value of the last call.

func (*VolumeAttachmentStatusApplyConfiguration) WithAttachmentMetadata

WithAttachmentMetadata puts the entries into the AttachmentMetadata field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the AttachmentMetadata field, overwriting an existing map entries in AttachmentMetadata field with the same key.

func (*VolumeAttachmentStatusApplyConfiguration) WithDetachError

WithDetachError sets the DetachError field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DetachError field is set to the value of the last call.

type VolumeAttributesClassApplyConfiguration

type VolumeAttributesClassApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object's metadata.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Name of the CSI driver
	// This field is immutable.
	DriverName *string `json:"driverName,omitempty"`
	// parameters hold volume attributes defined by the CSI driver. These values
	// are opaque to the Kubernetes and are passed directly to the CSI driver.
	// The underlying storage provider supports changing these attributes on an
	// existing volume, however the parameters field itself is immutable. To
	// invoke a volume update, a new VolumeAttributesClass should be created with
	// new parameters, and the PersistentVolumeClaim should be updated to reference
	// the new VolumeAttributesClass.
	//
	// This field is required and must contain at least one key/value pair.
	// The keys cannot be empty, and the maximum number of parameters is 512, with
	// a cumulative max size of 256K. If the CSI driver rejects invalid parameters,
	// the target PersistentVolumeClaim will be set to an "Infeasible" state in the
	// modifyVolumeStatus field.
	Parameters map[string]string `json:"parameters,omitempty"`
}

VolumeAttributesClassApplyConfiguration represents a declarative configuration of the VolumeAttributesClass type for use with apply.

VolumeAttributesClass represents a specification of mutable volume attributes defined by the CSI driver. The class can be specified during dynamic provisioning of PersistentVolumeClaims, and changed in the PersistentVolumeClaim spec after provisioning.

func ExtractVolumeAttributesClass

func ExtractVolumeAttributesClass(volumeAttributesClass *storagev1alpha1.VolumeAttributesClass, fieldManager string) (*VolumeAttributesClassApplyConfiguration, error)

ExtractVolumeAttributesClass extracts the applied configuration owned by fieldManager from volumeAttributesClass. If no managedFields are found in volumeAttributesClass for fieldManager, a VolumeAttributesClassApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. volumeAttributesClass must be a unmodified VolumeAttributesClass API object that was retrieved from the Kubernetes API. ExtractVolumeAttributesClass provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractVolumeAttributesClassFrom

func ExtractVolumeAttributesClassFrom(volumeAttributesClass *storagev1alpha1.VolumeAttributesClass, fieldManager string, subresource string) (*VolumeAttributesClassApplyConfiguration, error)

ExtractVolumeAttributesClassFrom extracts the applied configuration owned by fieldManager from volumeAttributesClass for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. volumeAttributesClass must be a unmodified VolumeAttributesClass API object that was retrieved from the Kubernetes API. ExtractVolumeAttributesClassFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func VolumeAttributesClass

func VolumeAttributesClass(name string) *VolumeAttributesClassApplyConfiguration

VolumeAttributesClass constructs a declarative configuration of the VolumeAttributesClass type for use with apply.

func (*VolumeAttributesClassApplyConfiguration) GetAPIVersion

func (b *VolumeAttributesClassApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*VolumeAttributesClassApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*VolumeAttributesClassApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*VolumeAttributesClassApplyConfiguration) GetNamespace

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (VolumeAttributesClassApplyConfiguration) IsApplyConfiguration

func (b VolumeAttributesClassApplyConfiguration) IsApplyConfiguration()

func (*VolumeAttributesClassApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*VolumeAttributesClassApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithDeletionGracePeriodSeconds

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithDriverName

WithDriverName sets the DriverName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DriverName field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*VolumeAttributesClassApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*VolumeAttributesClassApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*VolumeAttributesClassApplyConfiguration) WithParameters

WithParameters puts the entries into the Parameters field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Parameters field, overwriting an existing map entries in Parameters field with the same key.

func (*VolumeAttributesClassApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*VolumeAttributesClassApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type VolumeErrorApplyConfiguration

type VolumeErrorApplyConfiguration struct {
	// time represents the time the error was encountered.
	Time *v1.Time `json:"time,omitempty"`
	// message represents the error encountered during Attach or Detach operation.
	// This string maybe logged, so it should not contain sensitive
	// information.
	Message *string `json:"message,omitempty"`
	// errorCode is a numeric gRPC code representing the error encountered during Attach or Detach operations.
	//
	// This is an optional, alpha field that requires the MutableCSINodeAllocatableCount feature gate being enabled to be set.
	ErrorCode *int32 `json:"errorCode,omitempty"`
}

VolumeErrorApplyConfiguration represents a declarative configuration of the VolumeError type for use with apply.

VolumeError captures an error encountered during a volume operation.

func VolumeError

func VolumeError() *VolumeErrorApplyConfiguration

VolumeErrorApplyConfiguration constructs a declarative configuration of the VolumeError type for use with apply.

func (*VolumeErrorApplyConfiguration) WithErrorCode

WithErrorCode sets the ErrorCode field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ErrorCode field is set to the value of the last call.

func (*VolumeErrorApplyConfiguration) WithMessage

WithMessage sets the Message field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Message field is set to the value of the last call.

func (*VolumeErrorApplyConfiguration) WithTime

WithTime sets the Time field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Time field is set to the value of the last call.

Source Files

csistoragecapacity.go volumeattachment.go volumeattachmentsource.go volumeattachmentspec.go volumeattachmentstatus.go volumeattributesclass.go volumeerror.go

Version
v0.35.3
Published
Mar 19, 2026
Platform
linux/amd64
Imports
8 packages
Last checked
22 minutes ago

Tools for package owners.