package v1beta1

import "k8s.io/client-go/applyconfigurations/storagemigration/v1beta1"

Index

Types

type StorageVersionMigrationApplyConfiguration

type StorageVersionMigrationApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object metadata.
	// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Specification of the migration.
	Spec *StorageVersionMigrationSpecApplyConfiguration `json:"spec,omitempty"`
	// Status of the migration.
	Status *StorageVersionMigrationStatusApplyConfiguration `json:"status,omitempty"`
}

StorageVersionMigrationApplyConfiguration represents a declarative configuration of the StorageVersionMigration type for use with apply.

StorageVersionMigration represents a migration of stored data to the latest storage version.

func ExtractStorageVersionMigration

func ExtractStorageVersionMigration(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string) (*StorageVersionMigrationApplyConfiguration, error)

ExtractStorageVersionMigration extracts the applied configuration owned by fieldManager from storageVersionMigration. If no managedFields are found in storageVersionMigration for fieldManager, a StorageVersionMigrationApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. storageVersionMigration must be a unmodified StorageVersionMigration API object that was retrieved from the Kubernetes API. ExtractStorageVersionMigration provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractStorageVersionMigrationFrom

func ExtractStorageVersionMigrationFrom(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string, subresource string) (*StorageVersionMigrationApplyConfiguration, error)

ExtractStorageVersionMigrationFrom extracts the applied configuration owned by fieldManager from storageVersionMigration for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. storageVersionMigration must be a unmodified StorageVersionMigration API object that was retrieved from the Kubernetes API. ExtractStorageVersionMigrationFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractStorageVersionMigrationStatus

func ExtractStorageVersionMigrationStatus(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string) (*StorageVersionMigrationApplyConfiguration, error)

ExtractStorageVersionMigrationStatus extracts the applied configuration owned by fieldManager from storageVersionMigration for the status subresource.

func StorageVersionMigration

func StorageVersionMigration(name string) *StorageVersionMigrationApplyConfiguration

StorageVersionMigration constructs a declarative configuration of the StorageVersionMigration type for use with apply.

func (*StorageVersionMigrationApplyConfiguration) GetAPIVersion

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*StorageVersionMigrationApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*StorageVersionMigrationApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*StorageVersionMigrationApplyConfiguration) GetNamespace

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (StorageVersionMigrationApplyConfiguration) IsApplyConfiguration

func (b StorageVersionMigrationApplyConfiguration) IsApplyConfiguration()

func (*StorageVersionMigrationApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*StorageVersionMigrationApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithDeletionGracePeriodSeconds

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*StorageVersionMigrationApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*StorageVersionMigrationApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*StorageVersionMigrationApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*StorageVersionMigrationApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type StorageVersionMigrationSpecApplyConfiguration

type StorageVersionMigrationSpecApplyConfiguration struct {
	// The resource that is being migrated. The migrator sends requests to
	// the endpoint serving the resource.
	// Immutable.
	Resource *v1.GroupResourceApplyConfiguration `json:"resource,omitempty"`
}

StorageVersionMigrationSpecApplyConfiguration represents a declarative configuration of the StorageVersionMigrationSpec type for use with apply.

Spec of the storage version migration.

func StorageVersionMigrationSpec

func StorageVersionMigrationSpec() *StorageVersionMigrationSpecApplyConfiguration

StorageVersionMigrationSpecApplyConfiguration constructs a declarative configuration of the StorageVersionMigrationSpec type for use with apply.

func (*StorageVersionMigrationSpecApplyConfiguration) WithResource

WithResource sets the Resource field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Resource field is set to the value of the last call.

type StorageVersionMigrationStatusApplyConfiguration

type StorageVersionMigrationStatusApplyConfiguration struct {
	// The latest available observations of the migration's current state.
	Conditions []v1.ConditionApplyConfiguration `json:"conditions,omitempty"`
	// ResourceVersion to compare with the GC cache for performing the migration.
	// This is the current resource version of given group, version and resource when
	// kube-controller-manager first observes this StorageVersionMigration resource.
	ResourceVersion *string `json:"resourceVersion,omitempty"`
}

StorageVersionMigrationStatusApplyConfiguration represents a declarative configuration of the StorageVersionMigrationStatus type for use with apply.

Status of the storage version migration.

func StorageVersionMigrationStatus

func StorageVersionMigrationStatus() *StorageVersionMigrationStatusApplyConfiguration

StorageVersionMigrationStatusApplyConfiguration constructs a declarative configuration of the StorageVersionMigrationStatus type for use with apply.

func (*StorageVersionMigrationStatusApplyConfiguration) WithConditions

WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.

func (*StorageVersionMigrationStatusApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

Source Files

storageversionmigration.go storageversionmigrationspec.go storageversionmigrationstatus.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
6 packages
Last checked
6 days ago

Tools for package owners.