package v1alpha3
import "k8s.io/client-go/applyconfigurations/resource/v1alpha3"
Index ¶
- type DeviceTaintApplyConfiguration
- func DeviceTaint() *DeviceTaintApplyConfiguration
- func (b *DeviceTaintApplyConfiguration) WithEffect(value resourcev1alpha3.DeviceTaintEffect) *DeviceTaintApplyConfiguration
- func (b *DeviceTaintApplyConfiguration) WithKey(value string) *DeviceTaintApplyConfiguration
- func (b *DeviceTaintApplyConfiguration) WithTimeAdded(value v1.Time) *DeviceTaintApplyConfiguration
- func (b *DeviceTaintApplyConfiguration) WithValue(value string) *DeviceTaintApplyConfiguration
- type DeviceTaintRuleApplyConfiguration
- func DeviceTaintRule(name string) *DeviceTaintRuleApplyConfiguration
- func ExtractDeviceTaintRule(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string) (*DeviceTaintRuleApplyConfiguration, error)
- func ExtractDeviceTaintRuleFrom(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string, subresource string) (*DeviceTaintRuleApplyConfiguration, error)
- func ExtractDeviceTaintRuleStatus(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string) (*DeviceTaintRuleApplyConfiguration, error)
- func (b *DeviceTaintRuleApplyConfiguration) GetAPIVersion() *string
- func (b *DeviceTaintRuleApplyConfiguration) GetKind() *string
- func (b *DeviceTaintRuleApplyConfiguration) GetName() *string
- func (b *DeviceTaintRuleApplyConfiguration) GetNamespace() *string
- func (b DeviceTaintRuleApplyConfiguration) IsApplyConfiguration()
- func (b *DeviceTaintRuleApplyConfiguration) WithAPIVersion(value string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithAnnotations(entries map[string]string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithCreationTimestamp(value metav1.Time) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithFinalizers(values ...string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithGenerateName(value string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithGeneration(value int64) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithKind(value string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithLabels(entries map[string]string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithName(value string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithNamespace(value string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithResourceVersion(value string) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithSpec(value *DeviceTaintRuleSpecApplyConfiguration) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithStatus(value *DeviceTaintRuleStatusApplyConfiguration) *DeviceTaintRuleApplyConfiguration
- func (b *DeviceTaintRuleApplyConfiguration) WithUID(value types.UID) *DeviceTaintRuleApplyConfiguration
- type DeviceTaintRuleSpecApplyConfiguration
- func DeviceTaintRuleSpec() *DeviceTaintRuleSpecApplyConfiguration
- func (b *DeviceTaintRuleSpecApplyConfiguration) WithDeviceSelector(value *DeviceTaintSelectorApplyConfiguration) *DeviceTaintRuleSpecApplyConfiguration
- func (b *DeviceTaintRuleSpecApplyConfiguration) WithTaint(value *DeviceTaintApplyConfiguration) *DeviceTaintRuleSpecApplyConfiguration
- type DeviceTaintRuleStatusApplyConfiguration
- func DeviceTaintRuleStatus() *DeviceTaintRuleStatusApplyConfiguration
- func (b *DeviceTaintRuleStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *DeviceTaintRuleStatusApplyConfiguration
- type DeviceTaintSelectorApplyConfiguration
- func DeviceTaintSelector() *DeviceTaintSelectorApplyConfiguration
- func (b *DeviceTaintSelectorApplyConfiguration) WithDevice(value string) *DeviceTaintSelectorApplyConfiguration
- func (b *DeviceTaintSelectorApplyConfiguration) WithDriver(value string) *DeviceTaintSelectorApplyConfiguration
- func (b *DeviceTaintSelectorApplyConfiguration) WithPool(value string) *DeviceTaintSelectorApplyConfiguration
- type PoolStatusApplyConfiguration
- func PoolStatus() *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithAllocatedDevices(value int32) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithAvailableDevices(value int32) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithDriver(value string) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithGeneration(value int64) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithNodeName(value string) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithPoolName(value string) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithResourceSliceCount(value int32) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithTotalDevices(value int32) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithUnavailableDevices(value int32) *PoolStatusApplyConfiguration
- func (b *PoolStatusApplyConfiguration) WithValidationError(value string) *PoolStatusApplyConfiguration
- type ResourcePoolStatusRequestApplyConfiguration
- func ExtractResourcePoolStatusRequest(resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, fieldManager string) (*ResourcePoolStatusRequestApplyConfiguration, error)
- func ExtractResourcePoolStatusRequestFrom(resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, fieldManager string, subresource string) (*ResourcePoolStatusRequestApplyConfiguration, error)
- func ExtractResourcePoolStatusRequestStatus(resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, fieldManager string) (*ResourcePoolStatusRequestApplyConfiguration, error)
- func ResourcePoolStatusRequest(name string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) GetAPIVersion() *string
- func (b *ResourcePoolStatusRequestApplyConfiguration) GetKind() *string
- func (b *ResourcePoolStatusRequestApplyConfiguration) GetName() *string
- func (b *ResourcePoolStatusRequestApplyConfiguration) GetNamespace() *string
- func (b ResourcePoolStatusRequestApplyConfiguration) IsApplyConfiguration()
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithAPIVersion(value string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithAnnotations(entries map[string]string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithCreationTimestamp(value metav1.Time) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithFinalizers(values ...string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithGenerateName(value string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithGeneration(value int64) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithKind(value string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithLabels(entries map[string]string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithName(value string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithNamespace(value string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithResourceVersion(value string) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithSpec(value *ResourcePoolStatusRequestSpecApplyConfiguration) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithStatus(value *ResourcePoolStatusRequestStatusApplyConfiguration) *ResourcePoolStatusRequestApplyConfiguration
- func (b *ResourcePoolStatusRequestApplyConfiguration) WithUID(value types.UID) *ResourcePoolStatusRequestApplyConfiguration
- type ResourcePoolStatusRequestSpecApplyConfiguration
- func ResourcePoolStatusRequestSpec() *ResourcePoolStatusRequestSpecApplyConfiguration
- func (b *ResourcePoolStatusRequestSpecApplyConfiguration) WithDriver(value string) *ResourcePoolStatusRequestSpecApplyConfiguration
- func (b *ResourcePoolStatusRequestSpecApplyConfiguration) WithLimit(value int32) *ResourcePoolStatusRequestSpecApplyConfiguration
- func (b *ResourcePoolStatusRequestSpecApplyConfiguration) WithPoolName(value string) *ResourcePoolStatusRequestSpecApplyConfiguration
- type ResourcePoolStatusRequestStatusApplyConfiguration
- func ResourcePoolStatusRequestStatus() *ResourcePoolStatusRequestStatusApplyConfiguration
- func (b *ResourcePoolStatusRequestStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *ResourcePoolStatusRequestStatusApplyConfiguration
- func (b *ResourcePoolStatusRequestStatusApplyConfiguration) WithPoolCount(value int32) *ResourcePoolStatusRequestStatusApplyConfiguration
- func (b *ResourcePoolStatusRequestStatusApplyConfiguration) WithPools(values ...*PoolStatusApplyConfiguration) *ResourcePoolStatusRequestStatusApplyConfiguration
Types ¶
type DeviceTaintApplyConfiguration ¶
type DeviceTaintApplyConfiguration struct {
// The taint key to be applied to a device.
// Must be a label name.
Key *string `json:"key,omitempty"`
// The taint value corresponding to the taint key.
// Must be a label value.
Value *string `json:"value,omitempty"`
// The effect of the taint on claims that do not tolerate the taint
// and through such claims on the pods using them.
//
// Valid effects are None, NoSchedule and NoExecute. PreferNoSchedule as used for
// nodes is not valid here. More effects may get added in the future.
// Consumers must treat unknown effects like None.
Effect *resourcev1alpha3.DeviceTaintEffect `json:"effect,omitempty"`
// TimeAdded represents the time at which the taint was added or
// (only in a DeviceTaintRule) the effect was modified.
// Added automatically during create or update if not set.
//
// In addition, in a DeviceTaintRule a value provided during
// an update gets replaced with the current time if the provided
// value is the same as the old one and the new effect is different.
// Changing the key and/or value while keeping the effect unchanged
// is possible and does not update the time stamp because the eviction
// which uses it is either already started (NoExecute) or
// not started yet (NoEffect, NoSchedule).
TimeAdded *v1.Time `json:"timeAdded,omitempty"`
}
DeviceTaintApplyConfiguration represents a declarative configuration of the DeviceTaint type for use with apply.
The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.
func DeviceTaint ¶
func DeviceTaint() *DeviceTaintApplyConfiguration
DeviceTaintApplyConfiguration constructs a declarative configuration of the DeviceTaint type for use with apply.
func (*DeviceTaintApplyConfiguration) WithEffect ¶
func (b *DeviceTaintApplyConfiguration) WithEffect(value resourcev1alpha3.DeviceTaintEffect) *DeviceTaintApplyConfiguration
WithEffect sets the Effect field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Effect field is set to the value of the last call.
func (*DeviceTaintApplyConfiguration) WithKey ¶
func (b *DeviceTaintApplyConfiguration) WithKey(value string) *DeviceTaintApplyConfiguration
WithKey sets the Key field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Key field is set to the value of the last call.
func (*DeviceTaintApplyConfiguration) WithTimeAdded ¶
func (b *DeviceTaintApplyConfiguration) WithTimeAdded(value v1.Time) *DeviceTaintApplyConfiguration
WithTimeAdded sets the TimeAdded field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the TimeAdded field is set to the value of the last call.
func (*DeviceTaintApplyConfiguration) WithValue ¶
func (b *DeviceTaintApplyConfiguration) WithValue(value string) *DeviceTaintApplyConfiguration
WithValue sets the Value field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Value field is set to the value of the last call.
type DeviceTaintRuleApplyConfiguration ¶
type DeviceTaintRuleApplyConfiguration struct {
v1.TypeMetaApplyConfiguration `json:",inline"`
// Standard object metadata
*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
// Spec specifies the selector and one taint.
//
// Changing the spec automatically increments the metadata.generation number.
Spec *DeviceTaintRuleSpecApplyConfiguration `json:"spec,omitempty"`
// Status provides information about what was requested in the spec.
Status *DeviceTaintRuleStatusApplyConfiguration `json:"status,omitempty"`
}
DeviceTaintRuleApplyConfiguration represents a declarative configuration of the DeviceTaintRule type for use with apply.
DeviceTaintRule adds one taint to all devices which match the selector. This has the same effect as if the taint was specified directly in the ResourceSlice by the DRA driver.
func DeviceTaintRule ¶
func DeviceTaintRule(name string) *DeviceTaintRuleApplyConfiguration
DeviceTaintRule constructs a declarative configuration of the DeviceTaintRule type for use with apply.
func ExtractDeviceTaintRule ¶
func ExtractDeviceTaintRule(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string) (*DeviceTaintRuleApplyConfiguration, error)
ExtractDeviceTaintRule extracts the applied configuration owned by fieldManager from deviceTaintRule. If no managedFields are found in deviceTaintRule for fieldManager, a DeviceTaintRuleApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. deviceTaintRule must be a unmodified DeviceTaintRule API object that was retrieved from the Kubernetes API. ExtractDeviceTaintRule provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractDeviceTaintRuleFrom ¶
func ExtractDeviceTaintRuleFrom(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string, subresource string) (*DeviceTaintRuleApplyConfiguration, error)
ExtractDeviceTaintRuleFrom extracts the applied configuration owned by fieldManager from deviceTaintRule for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. deviceTaintRule must be a unmodified DeviceTaintRule API object that was retrieved from the Kubernetes API. ExtractDeviceTaintRuleFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractDeviceTaintRuleStatus ¶
func ExtractDeviceTaintRuleStatus(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string) (*DeviceTaintRuleApplyConfiguration, error)
ExtractDeviceTaintRuleStatus extracts the applied configuration owned by fieldManager from deviceTaintRule for the status subresource.
func (*DeviceTaintRuleApplyConfiguration) GetAPIVersion ¶
func (b *DeviceTaintRuleApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*DeviceTaintRuleApplyConfiguration) GetKind ¶
func (b *DeviceTaintRuleApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*DeviceTaintRuleApplyConfiguration) GetName ¶
func (b *DeviceTaintRuleApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*DeviceTaintRuleApplyConfiguration) GetNamespace ¶
func (b *DeviceTaintRuleApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (DeviceTaintRuleApplyConfiguration) IsApplyConfiguration ¶
func (b DeviceTaintRuleApplyConfiguration) IsApplyConfiguration()
func (*DeviceTaintRuleApplyConfiguration) WithAPIVersion ¶
func (b *DeviceTaintRuleApplyConfiguration) WithAPIVersion(value string) *DeviceTaintRuleApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithAnnotations ¶
func (b *DeviceTaintRuleApplyConfiguration) WithAnnotations(entries map[string]string) *DeviceTaintRuleApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*DeviceTaintRuleApplyConfiguration) WithCreationTimestamp ¶
func (b *DeviceTaintRuleApplyConfiguration) WithCreationTimestamp(value metav1.Time) *DeviceTaintRuleApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *DeviceTaintRuleApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *DeviceTaintRuleApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithDeletionTimestamp ¶
func (b *DeviceTaintRuleApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *DeviceTaintRuleApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithFinalizers ¶
func (b *DeviceTaintRuleApplyConfiguration) WithFinalizers(values ...string) *DeviceTaintRuleApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*DeviceTaintRuleApplyConfiguration) WithGenerateName ¶
func (b *DeviceTaintRuleApplyConfiguration) WithGenerateName(value string) *DeviceTaintRuleApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithGeneration ¶
func (b *DeviceTaintRuleApplyConfiguration) WithGeneration(value int64) *DeviceTaintRuleApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithKind ¶
func (b *DeviceTaintRuleApplyConfiguration) WithKind(value string) *DeviceTaintRuleApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithLabels ¶
func (b *DeviceTaintRuleApplyConfiguration) WithLabels(entries map[string]string) *DeviceTaintRuleApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*DeviceTaintRuleApplyConfiguration) WithName ¶
func (b *DeviceTaintRuleApplyConfiguration) WithName(value string) *DeviceTaintRuleApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithNamespace ¶
func (b *DeviceTaintRuleApplyConfiguration) WithNamespace(value string) *DeviceTaintRuleApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithOwnerReferences ¶
func (b *DeviceTaintRuleApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *DeviceTaintRuleApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*DeviceTaintRuleApplyConfiguration) WithResourceVersion ¶
func (b *DeviceTaintRuleApplyConfiguration) WithResourceVersion(value string) *DeviceTaintRuleApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithSpec ¶
func (b *DeviceTaintRuleApplyConfiguration) WithSpec(value *DeviceTaintRuleSpecApplyConfiguration) *DeviceTaintRuleApplyConfiguration
WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithStatus ¶
func (b *DeviceTaintRuleApplyConfiguration) WithStatus(value *DeviceTaintRuleStatusApplyConfiguration) *DeviceTaintRuleApplyConfiguration
WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.
func (*DeviceTaintRuleApplyConfiguration) WithUID ¶
func (b *DeviceTaintRuleApplyConfiguration) WithUID(value types.UID) *DeviceTaintRuleApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type DeviceTaintRuleSpecApplyConfiguration ¶
type DeviceTaintRuleSpecApplyConfiguration struct {
// DeviceSelector defines which device(s) the taint is applied to.
// All selector criteria must be satisfied for a device to
// match. The empty selector matches all devices. Without
// a selector, no devices are matches.
DeviceSelector *DeviceTaintSelectorApplyConfiguration `json:"deviceSelector,omitempty"`
// The taint that gets applied to matching devices.
Taint *DeviceTaintApplyConfiguration `json:"taint,omitempty"`
}
DeviceTaintRuleSpecApplyConfiguration represents a declarative configuration of the DeviceTaintRuleSpec type for use with apply.
DeviceTaintRuleSpec specifies the selector and one taint.
func DeviceTaintRuleSpec ¶
func DeviceTaintRuleSpec() *DeviceTaintRuleSpecApplyConfiguration
DeviceTaintRuleSpecApplyConfiguration constructs a declarative configuration of the DeviceTaintRuleSpec type for use with apply.
func (*DeviceTaintRuleSpecApplyConfiguration) WithDeviceSelector ¶
func (b *DeviceTaintRuleSpecApplyConfiguration) WithDeviceSelector(value *DeviceTaintSelectorApplyConfiguration) *DeviceTaintRuleSpecApplyConfiguration
WithDeviceSelector sets the DeviceSelector field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeviceSelector field is set to the value of the last call.
func (*DeviceTaintRuleSpecApplyConfiguration) WithTaint ¶
func (b *DeviceTaintRuleSpecApplyConfiguration) WithTaint(value *DeviceTaintApplyConfiguration) *DeviceTaintRuleSpecApplyConfiguration
WithTaint sets the Taint field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Taint field is set to the value of the last call.
type DeviceTaintRuleStatusApplyConfiguration ¶
type DeviceTaintRuleStatusApplyConfiguration struct {
// Conditions provide information about the state of the DeviceTaintRule
// and the cluster at some point in time,
// in a machine-readable and human-readable format.
//
// The following condition is currently defined as part of this API, more may
// get added:
// - Type: EvictionInProgress
// - Status: True if there are currently pods which need to be evicted, False otherwise
// (includes the effects which don't cause eviction).
// - Reason: not specified, may change
// - Message: includes information about number of pending pods and already evicted pods
// in a human-readable format, updated periodically, may change
//
// For `effect: None`, the condition above gets set once for each change to
// the spec, with the message containing information about what would happen
// if the effect was `NoExecute`. This feedback can be used to decide whether
// changing the effect to `NoExecute` will work as intended. It only gets
// set once to avoid having to constantly update the status.
//
// Must have 8 or fewer entries.
Conditions []v1.ConditionApplyConfiguration `json:"conditions,omitempty"`
}
DeviceTaintRuleStatusApplyConfiguration represents a declarative configuration of the DeviceTaintRuleStatus type for use with apply.
DeviceTaintRuleStatus provides information about an on-going pod eviction.
func DeviceTaintRuleStatus ¶
func DeviceTaintRuleStatus() *DeviceTaintRuleStatusApplyConfiguration
DeviceTaintRuleStatusApplyConfiguration constructs a declarative configuration of the DeviceTaintRuleStatus type for use with apply.
func (*DeviceTaintRuleStatusApplyConfiguration) WithConditions ¶
func (b *DeviceTaintRuleStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *DeviceTaintRuleStatusApplyConfiguration
WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.
type DeviceTaintSelectorApplyConfiguration ¶
type DeviceTaintSelectorApplyConfiguration struct {
// If driver is set, only devices from that driver are selected.
// This fields corresponds to slice.spec.driver.
Driver *string `json:"driver,omitempty"`
// If pool is set, only devices in that pool are selected.
//
// Also setting the driver name may be useful to avoid
// ambiguity when different drivers use the same pool name,
// but this is not required because selecting pools from
// different drivers may also be useful, for example when
// drivers with node-local devices use the node name as
// their pool name.
Pool *string `json:"pool,omitempty"`
// If device is set, only devices with that name are selected.
// This field corresponds to slice.spec.devices[].name.
//
// Setting also driver and pool may be required to avoid ambiguity,
// but is not required.
Device *string `json:"device,omitempty"`
}
DeviceTaintSelectorApplyConfiguration represents a declarative configuration of the DeviceTaintSelector type for use with apply.
DeviceTaintSelector defines which device(s) a DeviceTaintRule applies to. The empty selector matches all devices. Without a selector, no devices are matched.
func DeviceTaintSelector ¶
func DeviceTaintSelector() *DeviceTaintSelectorApplyConfiguration
DeviceTaintSelectorApplyConfiguration constructs a declarative configuration of the DeviceTaintSelector type for use with apply.
func (*DeviceTaintSelectorApplyConfiguration) WithDevice ¶
func (b *DeviceTaintSelectorApplyConfiguration) WithDevice(value string) *DeviceTaintSelectorApplyConfiguration
WithDevice sets the Device field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Device field is set to the value of the last call.
func (*DeviceTaintSelectorApplyConfiguration) WithDriver ¶
func (b *DeviceTaintSelectorApplyConfiguration) WithDriver(value string) *DeviceTaintSelectorApplyConfiguration
WithDriver sets the Driver field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Driver field is set to the value of the last call.
func (*DeviceTaintSelectorApplyConfiguration) WithPool ¶
func (b *DeviceTaintSelectorApplyConfiguration) WithPool(value string) *DeviceTaintSelectorApplyConfiguration
WithPool sets the Pool field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Pool field is set to the value of the last call.
type PoolStatusApplyConfiguration ¶
type PoolStatusApplyConfiguration struct {
// Driver is the DRA driver name for this pool.
// Must be a DNS subdomain (e.g., "gpu.example.com").
Driver *string `json:"driver,omitempty"`
// PoolName is the name of the pool.
// Must be a valid resource pool name (DNS subdomains separated by "/").
PoolName *string `json:"poolName,omitempty"`
// Generation is the pool generation observed across all ResourceSlices
// in this pool. Only the latest generation is reported. During a generation
// rollout, if not all slices at the latest generation have been published,
// the pool is included with a validationError and device counts unset.
Generation *int64 `json:"generation,omitempty"`
// ResourceSliceCount is the number of ResourceSlices that make up this pool.
// May be unset when validationError is set.
ResourceSliceCount *int32 `json:"resourceSliceCount,omitempty"`
// TotalDevices is the total number of devices in the pool across all slices.
// A value of 0 means the pool has no devices.
// May be unset when validationError is set.
TotalDevices *int32 `json:"totalDevices,omitempty"`
// AllocatedDevices is the number of devices currently allocated to claims.
// A value of 0 means no devices are allocated.
// May be unset when validationError is set.
AllocatedDevices *int32 `json:"allocatedDevices,omitempty"`
// AvailableDevices is the number of devices available for allocation.
// This equals TotalDevices - AllocatedDevices - UnavailableDevices.
// A value of 0 means no devices are currently available.
// May be unset when validationError is set.
AvailableDevices *int32 `json:"availableDevices,omitempty"`
// UnavailableDevices is the number of devices that are not available
// due to taints or other conditions, but are not allocated.
// A value of 0 means all unallocated devices are available.
// May be unset when validationError is set.
*int32 `json:"unavailableDevices,omitempty"`
// NodeName is the node this pool is associated with.
// When omitted, the pool is not associated with a specific node.
// Must be a valid DNS subdomain name (RFC1123).
NodeName *string `json:"nodeName,omitempty"`
// ValidationError is set when the pool's data could not be fully
// validated (e.g., incomplete slice publication). When set, device
// count fields and ResourceSliceCount may be unset.
ValidationError *string `json:"validationError,omitempty"`
}
PoolStatusApplyConfiguration represents a declarative configuration of the PoolStatus type for use with apply.
PoolStatus contains status information for a single resource pool.
func PoolStatus ¶
func PoolStatus() *PoolStatusApplyConfiguration
PoolStatusApplyConfiguration constructs a declarative configuration of the PoolStatus type for use with apply.
func (*PoolStatusApplyConfiguration) WithAllocatedDevices ¶
func (b *PoolStatusApplyConfiguration) WithAllocatedDevices(value int32) *PoolStatusApplyConfiguration
WithAllocatedDevices sets the AllocatedDevices field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the AllocatedDevices field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithAvailableDevices ¶
func (b *PoolStatusApplyConfiguration) WithAvailableDevices(value int32) *PoolStatusApplyConfiguration
WithAvailableDevices sets the AvailableDevices field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the AvailableDevices field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithDriver ¶
func (b *PoolStatusApplyConfiguration) WithDriver(value string) *PoolStatusApplyConfiguration
WithDriver sets the Driver field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Driver field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithGeneration ¶
func (b *PoolStatusApplyConfiguration) WithGeneration(value int64) *PoolStatusApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithNodeName ¶
func (b *PoolStatusApplyConfiguration) WithNodeName(value string) *PoolStatusApplyConfiguration
WithNodeName sets the NodeName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the NodeName field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithPoolName ¶
func (b *PoolStatusApplyConfiguration) WithPoolName(value string) *PoolStatusApplyConfiguration
WithPoolName sets the PoolName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the PoolName field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithResourceSliceCount ¶
func (b *PoolStatusApplyConfiguration) WithResourceSliceCount(value int32) *PoolStatusApplyConfiguration
WithResourceSliceCount sets the ResourceSliceCount field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceSliceCount field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithTotalDevices ¶
func (b *PoolStatusApplyConfiguration) WithTotalDevices(value int32) *PoolStatusApplyConfiguration
WithTotalDevices sets the TotalDevices field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the TotalDevices field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithUnavailableDevices ¶
func (b *PoolStatusApplyConfiguration) WithUnavailableDevices(value int32) *PoolStatusApplyConfiguration
WithUnavailableDevices sets the UnavailableDevices field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UnavailableDevices field is set to the value of the last call.
func (*PoolStatusApplyConfiguration) WithValidationError ¶
func (b *PoolStatusApplyConfiguration) WithValidationError(value string) *PoolStatusApplyConfiguration
WithValidationError sets the ValidationError field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ValidationError field is set to the value of the last call.
type ResourcePoolStatusRequestApplyConfiguration ¶
type ResourcePoolStatusRequestApplyConfiguration struct {
v1.TypeMetaApplyConfiguration `json:",inline"`
// Standard object metadata
*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
// Spec defines the filters for which pools to include in the status.
// The spec is immutable once created.
Spec *ResourcePoolStatusRequestSpecApplyConfiguration `json:"spec,omitempty"`
// Status is populated by the controller with the calculated pool status.
// When status is non-nil, the request is considered complete and the
// entire object becomes immutable.
Status *ResourcePoolStatusRequestStatusApplyConfiguration `json:"status,omitempty"`
}
ResourcePoolStatusRequestApplyConfiguration represents a declarative configuration of the ResourcePoolStatusRequest type for use with apply.
ResourcePoolStatusRequest triggers a one-time calculation of resource pool status based on the provided filters. Once status is set, the request is considered complete and will not be reprocessed. Users should delete and recreate requests to get updated information.
func ExtractResourcePoolStatusRequest ¶
func ExtractResourcePoolStatusRequest(resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, fieldManager string) (*ResourcePoolStatusRequestApplyConfiguration, error)
ExtractResourcePoolStatusRequest extracts the applied configuration owned by fieldManager from resourcePoolStatusRequest. If no managedFields are found in resourcePoolStatusRequest for fieldManager, a ResourcePoolStatusRequestApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. resourcePoolStatusRequest must be a unmodified ResourcePoolStatusRequest API object that was retrieved from the Kubernetes API. ExtractResourcePoolStatusRequest provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractResourcePoolStatusRequestFrom ¶
func ExtractResourcePoolStatusRequestFrom(resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, fieldManager string, subresource string) (*ResourcePoolStatusRequestApplyConfiguration, error)
ExtractResourcePoolStatusRequestFrom extracts the applied configuration owned by fieldManager from resourcePoolStatusRequest for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. resourcePoolStatusRequest must be a unmodified ResourcePoolStatusRequest API object that was retrieved from the Kubernetes API. ExtractResourcePoolStatusRequestFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractResourcePoolStatusRequestStatus ¶
func ExtractResourcePoolStatusRequestStatus(resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, fieldManager string) (*ResourcePoolStatusRequestApplyConfiguration, error)
ExtractResourcePoolStatusRequestStatus extracts the applied configuration owned by fieldManager from resourcePoolStatusRequest for the status subresource.
func ResourcePoolStatusRequest ¶
func ResourcePoolStatusRequest(name string) *ResourcePoolStatusRequestApplyConfiguration
ResourcePoolStatusRequest constructs a declarative configuration of the ResourcePoolStatusRequest type for use with apply.
func (*ResourcePoolStatusRequestApplyConfiguration) GetAPIVersion ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*ResourcePoolStatusRequestApplyConfiguration) GetKind ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*ResourcePoolStatusRequestApplyConfiguration) GetName ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*ResourcePoolStatusRequestApplyConfiguration) GetNamespace ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (ResourcePoolStatusRequestApplyConfiguration) IsApplyConfiguration ¶
func (b ResourcePoolStatusRequestApplyConfiguration) IsApplyConfiguration()
func (*ResourcePoolStatusRequestApplyConfiguration) WithAPIVersion ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithAPIVersion(value string) *ResourcePoolStatusRequestApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithAnnotations ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithAnnotations(entries map[string]string) *ResourcePoolStatusRequestApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*ResourcePoolStatusRequestApplyConfiguration) WithCreationTimestamp ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithCreationTimestamp(value metav1.Time) *ResourcePoolStatusRequestApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *ResourcePoolStatusRequestApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithDeletionTimestamp ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *ResourcePoolStatusRequestApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithFinalizers ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithFinalizers(values ...string) *ResourcePoolStatusRequestApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*ResourcePoolStatusRequestApplyConfiguration) WithGenerateName ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithGenerateName(value string) *ResourcePoolStatusRequestApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithGeneration ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithGeneration(value int64) *ResourcePoolStatusRequestApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithKind ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithKind(value string) *ResourcePoolStatusRequestApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithLabels ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithLabels(entries map[string]string) *ResourcePoolStatusRequestApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*ResourcePoolStatusRequestApplyConfiguration) WithName ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithName(value string) *ResourcePoolStatusRequestApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithNamespace ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithNamespace(value string) *ResourcePoolStatusRequestApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithOwnerReferences ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *ResourcePoolStatusRequestApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*ResourcePoolStatusRequestApplyConfiguration) WithResourceVersion ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithResourceVersion(value string) *ResourcePoolStatusRequestApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithSpec ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithSpec(value *ResourcePoolStatusRequestSpecApplyConfiguration) *ResourcePoolStatusRequestApplyConfiguration
WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithStatus ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithStatus(value *ResourcePoolStatusRequestStatusApplyConfiguration) *ResourcePoolStatusRequestApplyConfiguration
WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.
func (*ResourcePoolStatusRequestApplyConfiguration) WithUID ¶
func (b *ResourcePoolStatusRequestApplyConfiguration) WithUID(value types.UID) *ResourcePoolStatusRequestApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type ResourcePoolStatusRequestSpecApplyConfiguration ¶
type ResourcePoolStatusRequestSpecApplyConfiguration struct {
// Driver specifies the DRA driver name to filter pools.
// Only pools from ResourceSlices with this driver will be included.
// Must be a DNS subdomain (e.g., "gpu.example.com").
Driver *string `json:"driver,omitempty"`
// PoolName optionally filters to a specific pool name.
// If not specified, all pools from the specified driver are included.
// When specified, must be a non-empty valid resource pool name
// (DNS subdomains separated by "/").
PoolName *string `json:"poolName,omitempty"`
// Limit optionally specifies the maximum number of pools to return in the status.
// If more pools match the filter criteria, the response will be truncated
// (i.e., len(status.pools) < status.poolCount).
//
// Default: 100
// Minimum: 1
// Maximum: 1000
Limit *int32 `json:"limit,omitempty"`
}
ResourcePoolStatusRequestSpecApplyConfiguration represents a declarative configuration of the ResourcePoolStatusRequestSpec type for use with apply.
ResourcePoolStatusRequestSpec defines the filters for the pool status request.
func ResourcePoolStatusRequestSpec ¶
func ResourcePoolStatusRequestSpec() *ResourcePoolStatusRequestSpecApplyConfiguration
ResourcePoolStatusRequestSpecApplyConfiguration constructs a declarative configuration of the ResourcePoolStatusRequestSpec type for use with apply.
func (*ResourcePoolStatusRequestSpecApplyConfiguration) WithDriver ¶
func (b *ResourcePoolStatusRequestSpecApplyConfiguration) WithDriver(value string) *ResourcePoolStatusRequestSpecApplyConfiguration
WithDriver sets the Driver field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Driver field is set to the value of the last call.
func (*ResourcePoolStatusRequestSpecApplyConfiguration) WithLimit ¶
func (b *ResourcePoolStatusRequestSpecApplyConfiguration) WithLimit(value int32) *ResourcePoolStatusRequestSpecApplyConfiguration
WithLimit sets the Limit field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Limit field is set to the value of the last call.
func (*ResourcePoolStatusRequestSpecApplyConfiguration) WithPoolName ¶
func (b *ResourcePoolStatusRequestSpecApplyConfiguration) WithPoolName(value string) *ResourcePoolStatusRequestSpecApplyConfiguration
WithPoolName sets the PoolName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the PoolName field is set to the value of the last call.
type ResourcePoolStatusRequestStatusApplyConfiguration ¶
type ResourcePoolStatusRequestStatusApplyConfiguration struct {
// PoolCount is the total number of pools that matched the filter criteria,
// regardless of truncation. This helps users understand how many pools exist
// even when the response is truncated. A value of 0 means no pools matched
// the filter criteria.
PoolCount *int32 `json:"poolCount,omitempty"`
// Pools contains the first `spec.limit` matching pools, sorted by driver
// then pool name. If `len(pools) < poolCount`, the list was truncated.
// When omitted, no pools matched the request filters.
Pools []PoolStatusApplyConfiguration `json:"pools,omitempty"`
// Conditions provide information about the state of the request.
// A condition with type=Complete or type=Failed will always be set
// when the status is populated.
//
// Known condition types:
// - "Complete": True when the request has been processed successfully
// - "Failed": True when the request could not be processed
Conditions []v1.ConditionApplyConfiguration `json:"conditions,omitempty"`
}
ResourcePoolStatusRequestStatusApplyConfiguration represents a declarative configuration of the ResourcePoolStatusRequestStatus type for use with apply.
ResourcePoolStatusRequestStatus contains the calculated pool status information.
func ResourcePoolStatusRequestStatus ¶
func ResourcePoolStatusRequestStatus() *ResourcePoolStatusRequestStatusApplyConfiguration
ResourcePoolStatusRequestStatusApplyConfiguration constructs a declarative configuration of the ResourcePoolStatusRequestStatus type for use with apply.
func (*ResourcePoolStatusRequestStatusApplyConfiguration) WithConditions ¶
func (b *ResourcePoolStatusRequestStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *ResourcePoolStatusRequestStatusApplyConfiguration
WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.
func (*ResourcePoolStatusRequestStatusApplyConfiguration) WithPoolCount ¶
func (b *ResourcePoolStatusRequestStatusApplyConfiguration) WithPoolCount(value int32) *ResourcePoolStatusRequestStatusApplyConfiguration
WithPoolCount sets the PoolCount field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the PoolCount field is set to the value of the last call.
func (*ResourcePoolStatusRequestStatusApplyConfiguration) WithPools ¶
func (b *ResourcePoolStatusRequestStatusApplyConfiguration) WithPools(values ...*PoolStatusApplyConfiguration) *ResourcePoolStatusRequestStatusApplyConfiguration
WithPools adds the given value to the Pools field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Pools field.
Source Files ¶
devicetaint.go devicetaintrule.go devicetaintrulespec.go devicetaintrulestatus.go devicetaintselector.go poolstatus.go resourcepoolstatusrequest.go resourcepoolstatusrequestspec.go resourcepoolstatusrequeststatus.go
- Version
- v0.36.0-rc.1
- Published
- Apr 15, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 5 minutes ago –
Tools for package owners.