package v1alpha3

import "k8s.io/client-go/applyconfigurations/resource/v1alpha3"

Index

Types

type DeviceTaintApplyConfiguration

type DeviceTaintApplyConfiguration struct {
	// The taint key to be applied to a device.
	// Must be a label name.
	Key *string `json:"key,omitempty"`
	// The taint value corresponding to the taint key.
	// Must be a label value.
	Value *string `json:"value,omitempty"`
	// The effect of the taint on claims that do not tolerate the taint
	// and through such claims on the pods using them.
	//
	// Valid effects are None, NoSchedule and NoExecute. PreferNoSchedule as used for
	// nodes is not valid here. More effects may get added in the future.
	// Consumers must treat unknown effects like None.
	Effect *resourcev1alpha3.DeviceTaintEffect `json:"effect,omitempty"`
	// TimeAdded represents the time at which the taint was added.
	// Added automatically during create or update if not set.
	TimeAdded *v1.Time `json:"timeAdded,omitempty"`
}

DeviceTaintApplyConfiguration represents a declarative configuration of the DeviceTaint type for use with apply.

The device this taint is attached to has the "effect" on any claim which does not tolerate the taint and, through the claim, to pods using the claim.

func DeviceTaint

func DeviceTaint() *DeviceTaintApplyConfiguration

DeviceTaintApplyConfiguration constructs a declarative configuration of the DeviceTaint type for use with apply.

func (*DeviceTaintApplyConfiguration) WithEffect

WithEffect sets the Effect field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Effect field is set to the value of the last call.

func (*DeviceTaintApplyConfiguration) WithKey

WithKey sets the Key field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Key field is set to the value of the last call.

func (*DeviceTaintApplyConfiguration) WithTimeAdded

WithTimeAdded sets the TimeAdded field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the TimeAdded field is set to the value of the last call.

func (*DeviceTaintApplyConfiguration) WithValue

WithValue sets the Value field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Value field is set to the value of the last call.

type DeviceTaintRuleApplyConfiguration

type DeviceTaintRuleApplyConfiguration struct {
	v1.TypeMetaApplyConfiguration `json:",inline"`
	// Standard object metadata
	*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
	// Spec specifies the selector and one taint.
	//
	// Changing the spec automatically increments the metadata.generation number.
	Spec *DeviceTaintRuleSpecApplyConfiguration `json:"spec,omitempty"`
	// Status provides information about what was requested in the spec.
	Status *DeviceTaintRuleStatusApplyConfiguration `json:"status,omitempty"`
}

DeviceTaintRuleApplyConfiguration represents a declarative configuration of the DeviceTaintRule type for use with apply.

DeviceTaintRule adds one taint to all devices which match the selector. This has the same effect as if the taint was specified directly in the ResourceSlice by the DRA driver.

func DeviceTaintRule

func DeviceTaintRule(name string) *DeviceTaintRuleApplyConfiguration

DeviceTaintRule constructs a declarative configuration of the DeviceTaintRule type for use with apply.

func ExtractDeviceTaintRule

func ExtractDeviceTaintRule(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string) (*DeviceTaintRuleApplyConfiguration, error)

ExtractDeviceTaintRule extracts the applied configuration owned by fieldManager from deviceTaintRule. If no managedFields are found in deviceTaintRule for fieldManager, a DeviceTaintRuleApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. deviceTaintRule must be a unmodified DeviceTaintRule API object that was retrieved from the Kubernetes API. ExtractDeviceTaintRule provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractDeviceTaintRuleFrom

func ExtractDeviceTaintRuleFrom(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string, subresource string) (*DeviceTaintRuleApplyConfiguration, error)

ExtractDeviceTaintRuleFrom extracts the applied configuration owned by fieldManager from deviceTaintRule for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. deviceTaintRule must be a unmodified DeviceTaintRule API object that was retrieved from the Kubernetes API. ExtractDeviceTaintRuleFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.

func ExtractDeviceTaintRuleStatus

func ExtractDeviceTaintRuleStatus(deviceTaintRule *resourcev1alpha3.DeviceTaintRule, fieldManager string) (*DeviceTaintRuleApplyConfiguration, error)

ExtractDeviceTaintRuleStatus extracts the applied configuration owned by fieldManager from deviceTaintRule for the status subresource.

func (*DeviceTaintRuleApplyConfiguration) GetAPIVersion

func (b *DeviceTaintRuleApplyConfiguration) GetAPIVersion() *string

GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.

func (*DeviceTaintRuleApplyConfiguration) GetKind

GetKind retrieves the value of the Kind field in the declarative configuration.

func (*DeviceTaintRuleApplyConfiguration) GetName

GetName retrieves the value of the Name field in the declarative configuration.

func (*DeviceTaintRuleApplyConfiguration) GetNamespace

func (b *DeviceTaintRuleApplyConfiguration) GetNamespace() *string

GetNamespace retrieves the value of the Namespace field in the declarative configuration.

func (DeviceTaintRuleApplyConfiguration) IsApplyConfiguration

func (b DeviceTaintRuleApplyConfiguration) IsApplyConfiguration()

func (*DeviceTaintRuleApplyConfiguration) WithAPIVersion

WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithAnnotations

WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.

func (*DeviceTaintRuleApplyConfiguration) WithCreationTimestamp

WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithDeletionGracePeriodSeconds

func (b *DeviceTaintRuleApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *DeviceTaintRuleApplyConfiguration

WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithDeletionTimestamp

WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithFinalizers

WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.

func (*DeviceTaintRuleApplyConfiguration) WithGenerateName

WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithGeneration

WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithKind

WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithLabels

WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.

func (*DeviceTaintRuleApplyConfiguration) WithName

WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithNamespace

WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithOwnerReferences

WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.

func (*DeviceTaintRuleApplyConfiguration) WithResourceVersion

WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithSpec

WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithStatus

WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.

func (*DeviceTaintRuleApplyConfiguration) WithUID

WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.

type DeviceTaintRuleSpecApplyConfiguration

type DeviceTaintRuleSpecApplyConfiguration struct {
	// DeviceSelector defines which device(s) the taint is applied to.
	// All selector criteria must be satisfied for a device to
	// match. The empty selector matches all devices. Without
	// a selector, no devices are matches.
	DeviceSelector *DeviceTaintSelectorApplyConfiguration `json:"deviceSelector,omitempty"`
	// The taint that gets applied to matching devices.
	Taint *DeviceTaintApplyConfiguration `json:"taint,omitempty"`
}

DeviceTaintRuleSpecApplyConfiguration represents a declarative configuration of the DeviceTaintRuleSpec type for use with apply.

DeviceTaintRuleSpec specifies the selector and one taint.

func DeviceTaintRuleSpec

func DeviceTaintRuleSpec() *DeviceTaintRuleSpecApplyConfiguration

DeviceTaintRuleSpecApplyConfiguration constructs a declarative configuration of the DeviceTaintRuleSpec type for use with apply.

func (*DeviceTaintRuleSpecApplyConfiguration) WithDeviceSelector

WithDeviceSelector sets the DeviceSelector field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeviceSelector field is set to the value of the last call.

func (*DeviceTaintRuleSpecApplyConfiguration) WithTaint

WithTaint sets the Taint field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Taint field is set to the value of the last call.

type DeviceTaintRuleStatusApplyConfiguration

type DeviceTaintRuleStatusApplyConfiguration struct {
	// Conditions provide information about the state of the DeviceTaintRule
	// and the cluster at some point in time,
	// in a machine-readable and human-readable format.
	//
	// The following condition is currently defined as part of this API, more may
	// get added:
	// - Type: EvictionInProgress
	// - Status: True if there are currently pods which need to be evicted, False otherwise
	// (includes the effects which don't cause eviction).
	// - Reason: not specified, may change
	// - Message: includes information about number of pending pods and already evicted pods
	// in a human-readable format, updated periodically, may change
	//
	// For `effect: None`, the condition above gets set once for each change to
	// the spec, with the message containing information about what would happen
	// if the effect was `NoExecute`. This feedback can be used to decide whether
	// changing the effect to `NoExecute` will work as intended. It only gets
	// set once to avoid having to constantly update the status.
	//
	// Must have 8 or fewer entries.
	Conditions []v1.ConditionApplyConfiguration `json:"conditions,omitempty"`
}

DeviceTaintRuleStatusApplyConfiguration represents a declarative configuration of the DeviceTaintRuleStatus type for use with apply.

DeviceTaintRuleStatus provides information about an on-going pod eviction.

func DeviceTaintRuleStatus

func DeviceTaintRuleStatus() *DeviceTaintRuleStatusApplyConfiguration

DeviceTaintRuleStatusApplyConfiguration constructs a declarative configuration of the DeviceTaintRuleStatus type for use with apply.

func (*DeviceTaintRuleStatusApplyConfiguration) WithConditions

WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.

type DeviceTaintSelectorApplyConfiguration

type DeviceTaintSelectorApplyConfiguration struct {
	// If driver is set, only devices from that driver are selected.
	// This fields corresponds to slice.spec.driver.
	Driver *string `json:"driver,omitempty"`
	// If pool is set, only devices in that pool are selected.
	//
	// Also setting the driver name may be useful to avoid
	// ambiguity when different drivers use the same pool name,
	// but this is not required because selecting pools from
	// different drivers may also be useful, for example when
	// drivers with node-local devices use the node name as
	// their pool name.
	Pool *string `json:"pool,omitempty"`
	// If device is set, only devices with that name are selected.
	// This field corresponds to slice.spec.devices[].name.
	//
	// Setting also driver and pool may be required to avoid ambiguity,
	// but is not required.
	Device *string `json:"device,omitempty"`
}

DeviceTaintSelectorApplyConfiguration represents a declarative configuration of the DeviceTaintSelector type for use with apply.

DeviceTaintSelector defines which device(s) a DeviceTaintRule applies to. The empty selector matches all devices. Without a selector, no devices are matched.

func DeviceTaintSelector

func DeviceTaintSelector() *DeviceTaintSelectorApplyConfiguration

DeviceTaintSelectorApplyConfiguration constructs a declarative configuration of the DeviceTaintSelector type for use with apply.

func (*DeviceTaintSelectorApplyConfiguration) WithDevice

WithDevice sets the Device field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Device field is set to the value of the last call.

func (*DeviceTaintSelectorApplyConfiguration) WithDriver

WithDriver sets the Driver field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Driver field is set to the value of the last call.

func (*DeviceTaintSelectorApplyConfiguration) WithPool

WithPool sets the Pool field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Pool field is set to the value of the last call.

Source Files

devicetaint.go devicetaintrule.go devicetaintrulespec.go devicetaintrulestatus.go devicetaintselector.go

Version
v0.35.0
Published
Dec 17, 2025
Platform
linux/amd64
Imports
6 packages
Last checked
1 hour ago

Tools for package owners.