package v1beta1
import "k8s.io/client-go/applyconfigurations/storagemigration/v1beta1"
Index ¶
- type StorageVersionMigrationApplyConfiguration
- func ExtractStorageVersionMigration(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string) (*StorageVersionMigrationApplyConfiguration, error)
- func ExtractStorageVersionMigrationFrom(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string, subresource string) (*StorageVersionMigrationApplyConfiguration, error)
- func ExtractStorageVersionMigrationStatus(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string) (*StorageVersionMigrationApplyConfiguration, error)
- func StorageVersionMigration(name string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) GetAPIVersion() *string
- func (b *StorageVersionMigrationApplyConfiguration) GetKind() *string
- func (b *StorageVersionMigrationApplyConfiguration) GetName() *string
- func (b *StorageVersionMigrationApplyConfiguration) GetNamespace() *string
- func (b StorageVersionMigrationApplyConfiguration) IsApplyConfiguration()
- func (b *StorageVersionMigrationApplyConfiguration) WithAPIVersion(value string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithAnnotations(entries map[string]string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithCreationTimestamp(value metav1.Time) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithFinalizers(values ...string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithGenerateName(value string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithGeneration(value int64) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithKind(value string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithLabels(entries map[string]string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithName(value string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithNamespace(value string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithResourceVersion(value string) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithSpec(value *StorageVersionMigrationSpecApplyConfiguration) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithStatus(value *StorageVersionMigrationStatusApplyConfiguration) *StorageVersionMigrationApplyConfiguration
- func (b *StorageVersionMigrationApplyConfiguration) WithUID(value types.UID) *StorageVersionMigrationApplyConfiguration
- type StorageVersionMigrationSpecApplyConfiguration
- func StorageVersionMigrationSpec() *StorageVersionMigrationSpecApplyConfiguration
- func (b *StorageVersionMigrationSpecApplyConfiguration) WithResource(value *v1.GroupResourceApplyConfiguration) *StorageVersionMigrationSpecApplyConfiguration
- type StorageVersionMigrationStatusApplyConfiguration
- func StorageVersionMigrationStatus() *StorageVersionMigrationStatusApplyConfiguration
- func (b *StorageVersionMigrationStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *StorageVersionMigrationStatusApplyConfiguration
- func (b *StorageVersionMigrationStatusApplyConfiguration) WithResourceVersion(value string) *StorageVersionMigrationStatusApplyConfiguration
Types ¶
type StorageVersionMigrationApplyConfiguration ¶
type StorageVersionMigrationApplyConfiguration struct {
v1.TypeMetaApplyConfiguration `json:",inline"`
// Standard object metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
*v1.ObjectMetaApplyConfiguration `json:"metadata,omitempty"`
// Specification of the migration.
Spec *StorageVersionMigrationSpecApplyConfiguration `json:"spec,omitempty"`
// Status of the migration.
Status *StorageVersionMigrationStatusApplyConfiguration `json:"status,omitempty"`
}
StorageVersionMigrationApplyConfiguration represents a declarative configuration of the StorageVersionMigration type for use with apply.
StorageVersionMigration represents a migration of stored data to the latest storage version.
func ExtractStorageVersionMigration ¶
func ExtractStorageVersionMigration(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string) (*StorageVersionMigrationApplyConfiguration, error)
ExtractStorageVersionMigration extracts the applied configuration owned by fieldManager from storageVersionMigration. If no managedFields are found in storageVersionMigration for fieldManager, a StorageVersionMigrationApplyConfiguration is returned with only the Name, Namespace (if applicable), APIVersion and Kind populated. It is possible that no managed fields were found for because other field managers have taken ownership of all the fields previously owned by fieldManager, or because the fieldManager never owned fields any fields. storageVersionMigration must be a unmodified StorageVersionMigration API object that was retrieved from the Kubernetes API. ExtractStorageVersionMigration provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractStorageVersionMigrationFrom ¶
func ExtractStorageVersionMigrationFrom(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string, subresource string) (*StorageVersionMigrationApplyConfiguration, error)
ExtractStorageVersionMigrationFrom extracts the applied configuration owned by fieldManager from storageVersionMigration for the specified subresource. Pass an empty string for subresource to extract the main resource. Common subresources include "status", "scale", etc. storageVersionMigration must be a unmodified StorageVersionMigration API object that was retrieved from the Kubernetes API. ExtractStorageVersionMigrationFrom provides a way to perform a extract/modify-in-place/apply workflow. Note that an extracted apply configuration will contain fewer fields than what the fieldManager previously applied if another fieldManager has updated or force applied any of the previously applied fields.
func ExtractStorageVersionMigrationStatus ¶
func ExtractStorageVersionMigrationStatus(storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, fieldManager string) (*StorageVersionMigrationApplyConfiguration, error)
ExtractStorageVersionMigrationStatus extracts the applied configuration owned by fieldManager from storageVersionMigration for the status subresource.
func StorageVersionMigration ¶
func StorageVersionMigration(name string) *StorageVersionMigrationApplyConfiguration
StorageVersionMigration constructs a declarative configuration of the StorageVersionMigration type for use with apply.
func (*StorageVersionMigrationApplyConfiguration) GetAPIVersion ¶
func (b *StorageVersionMigrationApplyConfiguration) GetAPIVersion() *string
GetAPIVersion retrieves the value of the APIVersion field in the declarative configuration.
func (*StorageVersionMigrationApplyConfiguration) GetKind ¶
func (b *StorageVersionMigrationApplyConfiguration) GetKind() *string
GetKind retrieves the value of the Kind field in the declarative configuration.
func (*StorageVersionMigrationApplyConfiguration) GetName ¶
func (b *StorageVersionMigrationApplyConfiguration) GetName() *string
GetName retrieves the value of the Name field in the declarative configuration.
func (*StorageVersionMigrationApplyConfiguration) GetNamespace ¶
func (b *StorageVersionMigrationApplyConfiguration) GetNamespace() *string
GetNamespace retrieves the value of the Namespace field in the declarative configuration.
func (StorageVersionMigrationApplyConfiguration) IsApplyConfiguration ¶
func (b StorageVersionMigrationApplyConfiguration) IsApplyConfiguration()
func (*StorageVersionMigrationApplyConfiguration) WithAPIVersion ¶
func (b *StorageVersionMigrationApplyConfiguration) WithAPIVersion(value string) *StorageVersionMigrationApplyConfiguration
WithAPIVersion sets the APIVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the APIVersion field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithAnnotations ¶
func (b *StorageVersionMigrationApplyConfiguration) WithAnnotations(entries map[string]string) *StorageVersionMigrationApplyConfiguration
WithAnnotations puts the entries into the Annotations field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Annotations field, overwriting an existing map entries in Annotations field with the same key.
func (*StorageVersionMigrationApplyConfiguration) WithCreationTimestamp ¶
func (b *StorageVersionMigrationApplyConfiguration) WithCreationTimestamp(value metav1.Time) *StorageVersionMigrationApplyConfiguration
WithCreationTimestamp sets the CreationTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the CreationTimestamp field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithDeletionGracePeriodSeconds ¶
func (b *StorageVersionMigrationApplyConfiguration) WithDeletionGracePeriodSeconds(value int64) *StorageVersionMigrationApplyConfiguration
WithDeletionGracePeriodSeconds sets the DeletionGracePeriodSeconds field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionGracePeriodSeconds field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithDeletionTimestamp ¶
func (b *StorageVersionMigrationApplyConfiguration) WithDeletionTimestamp(value metav1.Time) *StorageVersionMigrationApplyConfiguration
WithDeletionTimestamp sets the DeletionTimestamp field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the DeletionTimestamp field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithFinalizers ¶
func (b *StorageVersionMigrationApplyConfiguration) WithFinalizers(values ...string) *StorageVersionMigrationApplyConfiguration
WithFinalizers adds the given value to the Finalizers field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Finalizers field.
func (*StorageVersionMigrationApplyConfiguration) WithGenerateName ¶
func (b *StorageVersionMigrationApplyConfiguration) WithGenerateName(value string) *StorageVersionMigrationApplyConfiguration
WithGenerateName sets the GenerateName field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the GenerateName field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithGeneration ¶
func (b *StorageVersionMigrationApplyConfiguration) WithGeneration(value int64) *StorageVersionMigrationApplyConfiguration
WithGeneration sets the Generation field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Generation field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithKind ¶
func (b *StorageVersionMigrationApplyConfiguration) WithKind(value string) *StorageVersionMigrationApplyConfiguration
WithKind sets the Kind field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Kind field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithLabels ¶
func (b *StorageVersionMigrationApplyConfiguration) WithLabels(entries map[string]string) *StorageVersionMigrationApplyConfiguration
WithLabels puts the entries into the Labels field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, the entries provided by each call will be put on the Labels field, overwriting an existing map entries in Labels field with the same key.
func (*StorageVersionMigrationApplyConfiguration) WithName ¶
func (b *StorageVersionMigrationApplyConfiguration) WithName(value string) *StorageVersionMigrationApplyConfiguration
WithName sets the Name field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Name field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithNamespace ¶
func (b *StorageVersionMigrationApplyConfiguration) WithNamespace(value string) *StorageVersionMigrationApplyConfiguration
WithNamespace sets the Namespace field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Namespace field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithOwnerReferences ¶
func (b *StorageVersionMigrationApplyConfiguration) WithOwnerReferences(values ...*v1.OwnerReferenceApplyConfiguration) *StorageVersionMigrationApplyConfiguration
WithOwnerReferences adds the given value to the OwnerReferences field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the OwnerReferences field.
func (*StorageVersionMigrationApplyConfiguration) WithResourceVersion ¶
func (b *StorageVersionMigrationApplyConfiguration) WithResourceVersion(value string) *StorageVersionMigrationApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithSpec ¶
func (b *StorageVersionMigrationApplyConfiguration) WithSpec(value *StorageVersionMigrationSpecApplyConfiguration) *StorageVersionMigrationApplyConfiguration
WithSpec sets the Spec field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Spec field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithStatus ¶
func (b *StorageVersionMigrationApplyConfiguration) WithStatus(value *StorageVersionMigrationStatusApplyConfiguration) *StorageVersionMigrationApplyConfiguration
WithStatus sets the Status field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Status field is set to the value of the last call.
func (*StorageVersionMigrationApplyConfiguration) WithUID ¶
func (b *StorageVersionMigrationApplyConfiguration) WithUID(value types.UID) *StorageVersionMigrationApplyConfiguration
WithUID sets the UID field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the UID field is set to the value of the last call.
type StorageVersionMigrationSpecApplyConfiguration ¶
type StorageVersionMigrationSpecApplyConfiguration struct {
// The resource that is being migrated. The migrator sends requests to
// the endpoint serving the resource.
// Immutable.
Resource *v1.GroupResourceApplyConfiguration `json:"resource,omitempty"`
}
StorageVersionMigrationSpecApplyConfiguration represents a declarative configuration of the StorageVersionMigrationSpec type for use with apply.
Spec of the storage version migration.
func StorageVersionMigrationSpec ¶
func StorageVersionMigrationSpec() *StorageVersionMigrationSpecApplyConfiguration
StorageVersionMigrationSpecApplyConfiguration constructs a declarative configuration of the StorageVersionMigrationSpec type for use with apply.
func (*StorageVersionMigrationSpecApplyConfiguration) WithResource ¶
func (b *StorageVersionMigrationSpecApplyConfiguration) WithResource(value *v1.GroupResourceApplyConfiguration) *StorageVersionMigrationSpecApplyConfiguration
WithResource sets the Resource field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the Resource field is set to the value of the last call.
type StorageVersionMigrationStatusApplyConfiguration ¶
type StorageVersionMigrationStatusApplyConfiguration struct {
// The latest available observations of the migration's current state.
Conditions []v1.ConditionApplyConfiguration `json:"conditions,omitempty"`
// ResourceVersion to compare with the GC cache for performing the migration.
// This is the current resource version of given group, version and resource when
// kube-controller-manager first observes this StorageVersionMigration resource.
ResourceVersion *string `json:"resourceVersion,omitempty"`
}
StorageVersionMigrationStatusApplyConfiguration represents a declarative configuration of the StorageVersionMigrationStatus type for use with apply.
Status of the storage version migration.
func StorageVersionMigrationStatus ¶
func StorageVersionMigrationStatus() *StorageVersionMigrationStatusApplyConfiguration
StorageVersionMigrationStatusApplyConfiguration constructs a declarative configuration of the StorageVersionMigrationStatus type for use with apply.
func (*StorageVersionMigrationStatusApplyConfiguration) WithConditions ¶
func (b *StorageVersionMigrationStatusApplyConfiguration) WithConditions(values ...*v1.ConditionApplyConfiguration) *StorageVersionMigrationStatusApplyConfiguration
WithConditions adds the given value to the Conditions field in the declarative configuration and returns the receiver, so that objects can be build by chaining "With" function invocations. If called multiple times, values provided by each call will be appended to the Conditions field.
func (*StorageVersionMigrationStatusApplyConfiguration) WithResourceVersion ¶
func (b *StorageVersionMigrationStatusApplyConfiguration) WithResourceVersion(value string) *StorageVersionMigrationStatusApplyConfiguration
WithResourceVersion sets the ResourceVersion field in the declarative configuration to the given value and returns the receiver, so that objects can be built by chaining "With" function invocations. If called multiple times, the ResourceVersion field is set to the value of the last call.
Source Files ¶
storageversionmigration.go storageversionmigrationspec.go storageversionmigrationstatus.go
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 6 days ago –
Tools for package owners.